#!/bin/bash

#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of WGBS methylation changes in ALL subtypes
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

# Set up the directory for the results:
#genomeDirectory <- ""
#rawWGBSDirectory <- ""
#tablesDirectory <- ""

# Create Bismark reference:
bismark_genome_preparation genomeDirectory/GRCh37

# Trim Fastq files:
trim_galore --paired rawWGBSDirectory/Human_H053-J01_good_1.fq.gz rawWGBSDirectory/Human_H053-J01_good_2.fq.gz --fastqc
trim_galore --paired rawWGBSDirectory/Human_H053-J02_good_1.fq.gz rawWGBSDirectory/Human_H053-J02_good_2.fq.gz --fastqc
trim_galore --paired rawWGBSDirectory/Human_H053-J03_good_1.fq.gz rawWGBSDirectory/Human_H053-J03_good_2.fq.gz --fastqc
trim_galore --paired rawWGBSDirectory/Human_H053-J04_good_1.fq.gz rawWGBSDirectory/Human_H053-J04_good_2.fq.gz --fastqc
trim_galore --paired rawWGBSDirectory/Human_H053-J05_good_1.fq.gz rawWGBSDirectory/Human_H053-J05_good_2.fq.gz --fastqc
trim_galore --paired rawWGBSDirectory/Human_H053-J06_good_1.fq.gz rawWGBSDirectory/Human_H053-J06_good_2.fq.gz --fastqc
trim_galore --paired rawWGBSDirectory/Human_H053-J07_good_1.fq.gz rawWGBSDirectory/Human_H053-J07_good_2.fq.gz --fastqc
trim_galore --paired rawWGBSDirectory/Human_H053-J08_good_1.fq.gz rawWGBSDirectory/Human_H053-J08_good_2.fq.gz --fastqc

# Map to genome:
bismark -N 1 -L 20 --genome genomeDirectory/GRCh37 -p 4 -q -1 rawWGBSDirectory/Human_H053-J01_good_1_val_1.fq.gz,rawWGBSDirectory/Human_H053-J02_good_1_val_1.fq.gz,rawWGBSDirectory/Human_H053-J03_good_1_val_1.fq.gz,rawWGBSDirectory/Human_H053-J04_good_1_val_1.fq.gz,rawWGBSDirectory/Human_H053-J05_good_1_val_1.fq.gz,rawWGBSDirectory/Human_H053-J06_good_1_val_1.fq.gz,rawWGBSDirectory/Human_H053-J07_good_1_val_1.fq.gz,rawWGBSDirectory/Human_H053-J08_good_1_val_1.fq.gz -2 rawWGBSDirectory/Human_H053-J01_good_2_val_2.fq.gz,rawWGBSDirectory/Human_H053-J02_good_2_val_2.fq.gz,rawWGBSDirectory/Human_H053-J03_good_2_val_2.fq.gz,rawWGBSDirectory/Human_H053-J04_good_2_val_2.fq.gz,rawWGBSDirectory/Human_H053-J05_good_2_val_2.fq.gz,rawWGBSDirectory/Human_H053-J06_good_2_val_2.fq.gz,rawWGBSDirectory/Human_H053-J07_good_2_val_2.fq.gz,rawWGBSDirectory/Human_H053-J08_good_2_val_2.fq.gz

# Sort and index BAM files:
samtools sort Human_H053-J01_good_1_val_1_bismark_bt2_pe.bam Human_H053-J01_good_1_val_1_bismark_bt2_pe.sorted
samtools index Human_H053-J01_good_1_val_1_bismark_bt2_pe.sorted.bam

samtools sort Human_H053-J02_good_1_val_1_bismark_bt2_pe.bam Human_H053-J02_good_1_val_1_bismark_bt2_pe.sorted
samtools index Human_H053-J02_good_1_val_1_bismark_bt2_pe.sorted.bam

samtools sort Human_H053-J03good_1_val_1_bismark_bt2_pe.bam Human_H053-J03_good_1_val_1_bismark_bt2_pe.sorted
samtools index Human_H053-J03_good_1_val_1_bismark_bt2_pe.sorted.bam

samtools sort Human_H053-J04_good_1_val_1_bismark_bt2_pe.bam Human_H053-J04_good_1_val_1_bismark_bt2_pe.sorted
samtools index Human_H053-J04_good_1_val_1_bismark_bt2_pe.sorted.bam

samtools sort Human_H053-J05_good_1_val_1_bismark_bt2_pe.bam Human_H053-J05_good_1_val_1_bismark_bt2_pe.sorted
samtools index Human_H053-J05_good_1_val_1_bismark_bt2_pe.sorted.bam

samtools sort Human_H053-J06_good_1_val_1_bismark_bt2_pe.bam Human_H053-J06_good_1_val_1_bismark_bt2_pe.sorted
samtools index Human_H053-J06_good_1_val_1_bismark_bt2_pe.sorted.bam

samtools sort Human_H053-J07_good_1_val_1_bismark_bt2_pe.bam Human_H053-J07_good_1_val_1_bismark_bt2_pe.sorted
samtools index Human_H053-J07_good_1_val_1_bismark_bt2_pe.sorted.bam

samtools sort Human_H053-J08_good_1_val_1_bismark_bt2_pe.bam Human_H053-J08_good_1_val_1_bismark_bt2_pe.sorted
samtools index Human_H053-J08_good_1_val_1_bismark_bt2_pe.sorted.bam
