#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of WGBS methylation changes in ALL subtypes
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

# Set up the directory for the results:
tablesDirectory <- ""

library(methylKit)
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
library(genomation)

setwd(tablesDirectory)

# Load and process the txt files (should be sorted before proceed with this step):
file.list.CpG =list("./WGBS_analyses/MLL-AF4_1_CpG.txt",
                    "./WGBS_analyses/MLL-AF4_2_CpG.txt",
                    "./WGBS_analyses/MLL-AF9_1_CpG.txt",
                    "./WGBS_analyses/MLL-AF9_2_CpG.txt",
                    "./WGBS_analyses/non-MLL_1_CpG.txt",
                    "./WGBS_analyses/non-MLL_2_CpG.txt",
                    "./WGBS_analyses/BCP_1_CpG.txt",
                    "./WGBS_analyses/BCP_2_CpG.txt")

objs_cpg = methRead(location=file.list.CpG , sample.id=list("MLL-AF4_1", "MLL-AF4_2", "MLL-AF9_1", "MLL-AF9_2", "non-MLL_1", "non-MLL_2", "BCP_1", "BCP_2"), assembly="hg19", mincov=10, treatment=c(1,1,1,1,1,1,0,0))

# Filter by depth coverage:
filtered.objs_cpg = filterByCoverage(objs_cpg,lo.count=10,lo.perc=NULL, hi.count=NULL,hi.perc=99.9)
filtered.objs_cpg_tiles = tileMethylCounts(filtered.objs_cpg,win.size=10000,step.size=10000)

# Generate basic statistics plots:
pdf("histograms_percentage_methylation_cpg.pdf", paper="a4r", height=21, width=28, onefile=TRUE)
getMethylationStats(filtered.objs_cpg_tiles[[1]],plot=TRUE,both.strands=FALSE)
getMethylationStats(filtered.objs_cpg_tiles[[2]],plot=TRUE,both.strands=FALSE)
getMethylationStats(filtered.objs_cpg_tiles[[3]],plot=TRUE,both.strands=FALSE)
getMethylationStats(filtered.objs_cpg_tiles[[4]],plot=TRUE,both.strands=FALSE)
getMethylationStats(filtered.objs_cpg_tiles[[5]],plot=TRUE,both.strands=FALSE)
getMethylationStats(filtered.objs_cpg_tiles[[6]],plot=TRUE,both.strands=FALSE)
getMethylationStats(filtered.objs_cpg_tiles[[7]],plot=TRUE,both.strands=FALSE)
getMethylationStats(filtered.objs_cpg_tiles[[8]],plot=TRUE,both.strands=FALSE)
dev.off()

pdf("histograms_coverage_methylation_cpg.pdf", paper="a4r", height=21, width=28, onefile=TRUE)
getCoverageStats(filtered.objs_cpg_tiles[[1]],plot=TRUE,both.strands=FALSE)
getCoverageStats(filtered.objs_cpg_tiles[[2]],plot=TRUE,both.strands=FALSE)
getCoverageStats(filtered.objs_cpg_tiles[[3]],plot=TRUE,both.strands=FALSE)
getCoverageStats(filtered.objs_cpg_tiles[[4]],plot=TRUE,both.strands=FALSE)
getCoverageStats(filtered.objs_cpg_tiles[[5]],plot=TRUE,both.strands=FALSE)
getCoverageStats(filtered.objs_cpg_tiles[[6]],plot=TRUE,both.strands=FALSE)
getCoverageStats(filtered.objs_cpg_tiles[[7]],plot=TRUE,both.strands=FALSE)
getCoverageStats(filtered.objs_cpg_tiles[[8]],plot=TRUE,both.strands=FALSE)
dev.off()

# Filter by common Tiles:
meth_cpg_tiles = unite(filtered.objs_cpg_tiles, destrand=FALSE, min.per.group = 1L)
chrlist <- c("1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "X", "Y")
meth_cpg_tiles <- meth_cpg_tiles[which(meth_cpg_tiles$chr %in% chrlist),]
meth_cpg_tiles$chr <- factor(meth_cpg_tiles$chr, levels = chrlist)
meth_cpg_tiles_2 <- getData(meth_cpg_tiles)
meth_cpg_tiles_2$MLL_AF4_1 <- meth_cpg_tiles$numCs1 / meth_cpg_tiles$coverage1
meth_cpg_tiles_2$MLL_AF4_2 <- meth_cpg_tiles$numCs2 / meth_cpg_tiles$coverage2
meth_cpg_tiles_2$MLL_AF9_1 <- meth_cpg_tiles$numCs3 / meth_cpg_tiles$coverage3
meth_cpg_tiles_2$MLL_AF9_2 <- meth_cpg_tiles$numCs4 / meth_cpg_tiles$coverage4
meth_cpg_tiles_2$non_MLL_1 <- meth_cpg_tiles$numCs5 / meth_cpg_tiles$coverage5
meth_cpg_tiles_2$non_MLL_2 <- meth_cpg_tiles$numCs6 / meth_cpg_tiles$coverage6
meth_cpg_tiles_2$ProB_1 <- meth_cpg_tiles$numCs7 / meth_cpg_tiles$coverage7
meth_cpg_tiles_2$ProB_2 <- meth_cpg_tiles$numCs8 / meth_cpg_tiles$coverage8
meth_cpg_tiles_2 <- meth_cpg_tiles_2[,c(1:4,29:36)]
write.table(meth_cpg_tiles_2, file = "bVals_meth_cpg_tiles_matrix.txt", sep = "\t", quote = F, col.names = T)

