#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of WGBS methylation changes in ALL subtypes
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

# Set up the directory for the results:
tablesDirectory <- ""

library(ggplot2)
library(reshape2)
library(RColorBrewer)
library(gridExtra)
theme_set(theme_bw())

setwd("tablesDirectory")

# Load and process the txt files (should be sorted before proceed with this step):
Tiles <- read.csv(file = "bVals_meth_cpg_tiles_matrix.txt", sep = "\t", stringsAsFactors = F)

# Tune up the tables:
names_Tiles <- paste(Tiles$chr, Tiles$start, Tiles$end, Tiles$strand, sep = "_")
rownames(Tiles) <- names_Tiles
Tiles <- Tiles[,5:12]

bVals_Tiles <- melt(Tiles)
bVals_Tiles <- bVals_Tiles[complete.cases(bVals_Tiles),]

# generate boxplots:
colors_cells <- t(data.frame(MLL_AF4_1 = "#D53E4F", MLL_AF4_2 = "#D53E4F", MLL_AF9_1 = "#2eaa6c", MLL_AF9_2 = "#2eaa6c", non_MLL_1 = "#e8db4c", non_MLL_2 = "#e8db4c", BCP_1 = "#3288BD", BCP_2 = "#3288BD"))
colnames(colors_cells) <- "color"

pdf("violinplots_all_tiles_10000bp_WGBS.pdf", paper="a4r", height=12, width=16, onefile=TRUE)
b <- ggplot(bVals_Tiles, aes(variable, value, fill = as.factor(variable)))
b + geom_violin(width=1) + geom_boxplot(width=0.1, outlier.shape = NA) + theme(axis.text.x = element_text(angle = 65, vjust = 0.6), legend.position = "none") + labs(title = "DNA methylation Tiles", x = "cells", y = "B-Value") + scale_fill_manual(values = c("#D53E4F", "#D53E4F", "#2eaa6c", "#2eaa6c", "#e8db4c", "#e8db4c", "#3288BD", "#3288BD"))
dev.off()

png(filename = "violinplots_all_tiles_10000bp_WGBS.png", width = 480, height = 480, units = "px", pointsize = 12)
b <- ggplot(bVals_Tiles, aes(variable, value, fill = as.factor(variable)))
b + geom_violin() + geom_boxplot(width=0.1, outlier.shape = NA) + theme(axis.text.x = element_text(angle = 65, vjust = 0.6), legend.position = "none") + labs(title = "DNA methylation Tiles", x = "cells", y = "B-Value") + scale_fill_manual(values = c("#D53E4F", "#D53E4F", "#2eaa6c", "#2eaa6c", "#e8db4c", "#e8db4c", "#3288BD", "#3288BD"))
dev.off()
