#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of WGBS methylation changes in ALL subtypes
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

# Set up the directory for the results:
tablesDirectory <- ""
resultsDirectory <- ""

library(GenomicRanges)
library(ChIPpeakAnno)
library(Vennerable)
library(ggplot2)

# Load the Vennerable function:
venn_cnt2venn <- function(venn_cnt){
  n <- which(colnames(venn_cnt)=="Counts") - 1
  SetNames=colnames(venn_cnt)[1:n]
  Weight=venn_cnt[,"Counts"]
  names(Weight) <- apply(venn_cnt[,1:n], 1, paste, collapse="")
  Venn(SetNames=SetNames, Weight=Weight)
}

# Load the DMR files:
AF4 <- read.csv(paste(tablesDirectory, "dmrs_Bsseq_B20_AF4.txt", sep = "/"), sep = "\t", stringsAsFactors = F)
AF4_up <- AF4[which(AF4$direction == "hyper"),]
AF4_down <- AF4[which(AF4$direction == "hypo"),]
AF9 <- read.csv(paste(tablesDirectory,"dmrs_Bsseq_B20_AF9.txt", sep = "/"), sep = "\t", stringsAsFactors = F)
AF9_up <- AF9[which(AF9$direction == "hyper"),]
AF9_down <- AF9[which(AF9$direction == "hypo"),]
nonMLL <- read.csv(paste(tablesDirectory,"dmrs_Bsseq_B20_non_MLL.txt", sep = "/"), sep = "\t", stringsAsFactors = F)
nonMLL_up <- nonMLL[which(nonMLL$direction == "hyper"),]
nonMLL_down <- nonMLL[which(nonMLL$direction == "hypo"),]

# Convert to Granges objects:
AF4_up <- makeGRangesFromDataFrame(df = AF4_up, keep.extra.columns = T)
AF4_down <- makeGRangesFromDataFrame(df = AF4_down, keep.extra.columns = T)
AF9_up <- makeGRangesFromDataFrame(df = AF9_up, keep.extra.columns = T)
AF9_down <- makeGRangesFromDataFrame(df = AF9_down, keep.extra.columns = T)
nonMLL_up <- makeGRangesFromDataFrame(df = nonMLL_up, keep.extra.columns = T)
nonMLL_down <- makeGRangesFromDataFrame(df = nonMLL_down, keep.extra.columns = T)

# Get intersects between datasets:
res_up <- makeVennDiagram(Peaks=list(AF4_up, AF9_up, nonMLL_up), NameOfPeaks=c("AF4_up", "AF9_up", "nonMLL_up"))
res_down <- makeVennDiagram(Peaks=list(AF4_down, AF9_down, nonMLL_down), NameOfPeaks=c("AF4_down", "AF9_down", "nonMLL_down"))

v_up <- venn_cnt2venn(res_up$vennCounts)
v_down <- venn_cnt2venn(res_down$vennCounts)
pdf(file = paste(resultsDirectory, "venn_diagrams_DMRs_leukemias.pdf", sep = "/"), paper = "a4r", height = 21, width = 28, onefile = T)
plot(v_up)
plot(v_down)
dev.off()

# Plot DMR width:
# Load the DMR files:
AF4 <- read.csv(paste(tablesDirectory, "dmrs_Bsseq_B20_AF4.txt", sep = "/"), sep = "\t", stringsAsFactors = F)
AF4_up <- AF4[which(AF4$direction == "hyper"),]
AF4_up$Name <- "AF4_up"
AF4_down <- AF4[which(AF4$direction == "hypo"),]
AF4_down$Name <- "AF4_down"
AF9 <- read.csv(paste(tablesDirectory, "dmrs_Bsseq_B20_AF9.txt", sep = "/"), sep = "\t", stringsAsFactors = F)
AF9_up <- AF9[which(AF9$direction == "hyper"),]
AF9_up$Name <- "AF9_up"
AF9_down <- AF9[which(AF9$direction == "hypo"),]
AF9_down$Name <- "AF9_down"
nonMLL <- read.csv(paste(tablesDirectory, "dmrs_Bsseq_B20_non_MLL.txt", sep = "/"), sep = "\t", stringsAsFactors = F)
nonMLL_up <- nonMLL[which(nonMLL$direction == "hyper"),]
nonMLL_up$Name <- "nonMLL_up"
nonMLL_down <- nonMLL[which(nonMLL$direction == "hypo"),]
nonMLL_down$Name <- "nonMLL_down"

# Plot DMR witdh:
pdf(file = paste(resultsDIrectory, "width_DMRs_leukemias.pdf", sep = "/"), paper = "a4r", height = 21, width = 28, onefile = T)
bVals <- rbind(AF4_up[,c("Name", "width")], AF4_down[,c("Name", "width")], AF9_up[,c("Name", "width")], AF9_down[,c("Name", "width")], nonMLL_up[,c("Name", "width")], nonMLL_down[,c("Name", "width")])
b <- ggplot(bVals, aes(Name, width, fill = Name))
b + geom_violin(width=1) + geom_boxplot(width=0.1, outlier.shape = NA, fill = "white") + theme(axis.text.x = element_text(angle = 65, vjust = 0.6), legend.position = "none") + labs(title = "DMR width", x = "cells", y = "width (bp)") + scale_fill_manual(values = c("#D53E4F", "#D53E4F", "#2eaa6c", "#2eaa6c", "#e8db4c", "#e8db4c")) + theme_bw()
dev.off()
