#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of WGBS methylation changes in ALL subtypes
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

# Set up the directory for the results:
tablesDirectory <- ""
resultsDirectory <- ""

library(dplyr)
library(tidyr)
library(reshape2)

library(LOLA)

tablesDirectory <- ""

# Load the datasets to establish to plot the pie charts:
# Run this script for each dataset (AF4, AF9, nonMLL)
setwd(tablesDirectory)
allprobes_cpg <- read.csv(file = "All_annotations_leukemia_background.txt", sep = "\t", stringsAsFactors = F)
significant_cpgs <- read.csv(file = "./dmrs_Bsseq_B20_non_MLL.txt", sep = "\t", stringsAsFactors = F)
hypermethylationprobes <- significant_cpgs[which(significant_cpgs$direction == "hyper"),]
hypomethylationprobes <- significant_cpgs[which(significant_cpgs$direction == "hypo"),]

# Generate Granges files for the hyper and the hypomethylated probes:
hypermethylationprobes <- hypermethylationprobes[order(hypermethylationprobes[,"chr"], hypermethylationprobes[,"start"]),]
regionSethyper <- makeGRangesFromDataFrame(hypermethylationprobes, ignore.strand = TRUE, seqnames.field = "chr", start.field = "start", end.field = "end")
hypomethylationprobes <- hypomethylationprobes[order(hypomethylationprobes[,"chr"], hypomethylationprobes[,"start"]),]
regionSethypo <- makeGRangesFromDataFrame(hypomethylationprobes, ignore.strand = TRUE, seqnames.field = "chr", start.field = "start", end.field = "end")
allprobes_cpg <- allprobes_cpg[order(allprobes_cpg[,"seqnames"], allprobes_cpg[,"start"]),]
regionSetAll = makeGRangesFromDataFrame(allprobes_cpg, ignore.strand = TRUE, seqnames.field = "seqnames", start.field = "start", end.field = "end")

# Load the databases with the Regions of Interest (Create repeat library following LOLA guidelines)
regionDB <- loadRegionDB(dbLocation = "~/Databases/Repeats", collections = "Repeats")

# Generate tables from lists (probes)
userSets = GRangesList(hyper = regionSethyper, hypo = regionSethypo)

locResults_hyper = runLOLA(userSets[1], regionSetAll, regionDB, cores=4)
locResults_hypo = runLOLA(userSets[2], regionSetAll, regionDB, cores=4)

write.table(locResults_hyper, file = paste(tablesDirectory,"enrichment_repeats_hyper_DMRs_non_MLL.txt", sep = ""), quote = F, col.names = T, row.names = F, sep = "\t")
write.table(locResults_hypo, file = paste(tablesDirectory,"enrichment_repeats_hypo_DMRs_non_MLL.txt", sep = ""), quote = F, col.names = T, row.names = F, sep = "\t")

