#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of Methylation array data (850K)
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

library(ggplot2)
library(reshape2)
library(RColorBrewer)
library(gridExtra)
theme_set(theme_bw())

dataDirectory1 <- ""
dataDirectory2 <- ""
resultsDirectory <-""

# Load the files:
setwd(dataDirectory1)
LINEL1_probes <- read.csv(file = "LINEL1_probes.txt", sep = "\t", header = T, stringsAsFactors = F)

setwd(dataDirectory2)
all_bVals <- read.csv("bVals.txt",header=TRUE, sep = "\t")
all_bVals$meanAF4 <- rowMeans(all_bVals[,c(1:37)])
all_bVals$meanAF9 <- rowMeans(all_bVals[,c(40:51)])
all_bVals$meanGERM <- rowMeans(all_bVals[,c(57:76)])
all_bVals$meanproB <- rowMeans(all_bVals[,c(39,52:56)])
all_bVals$meanB <- all_bVals[,38]
all_bVals <- all_bVals[,c(77:81)]
colnames(all_bVals) <- c("MLLAF4", "MLLAF9", "nonMLL", "ProB", "B")

# filter the files to generate the tables for the analyses:
bVals_LINEL1 <- all_bVals[LINEL1_probes$Name, ]

# tune up the tables:
bVals_LINEL12 <- melt(bVals_LINEL1)

# generate boxplots:
colors_cells <- t(data.frame(MLLAF4 = "#D53E4F", MLLAF9 = "#2eaa6c", nonMLL = "#e8db4c", ProB = "#3288BD", B = "#5e4fa2"))
colnames(colors_cells) <- "color"


# Generate violplots:

pdf(file=paste(resultsDirectory, "Violplots_bVals_infant_leukemia_repeats_hg19.pdf", sep = "/"), paper="a4r", height=21, width=28, onefile=TRUE)

c <- ggplot(bVals_LINEL12, aes(variable, value, fill = as.factor(variable)))
c + geom_violin(width=1) + geom_boxplot(width=0.1, outlier.shape = NA) + theme(axis.text.x = element_text(angle=65, vjust=0.6), legend.position = "none") + labs(title="LINEL1 repeats", caption=paste("n = ", nrow(bVals_LINEL1), sep = ""), x="Cell type", y="b-Value") + scale_fill_manual(values=c("#D53E4F", "#2eaa6c", "#e8db4c", "#3288BD", "#5e4fa2"))

dev.off()
