#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of Methylation array data (850K)
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

# Load the required packages:
library("genefilter")
library("pheatmap")
library("RColorBrewer")
library("gplots")

options("width"=110) #  using R in terminal mode on Linux, making easier the inspection of data sets
###################################################################
#####                       READING DATA                      #####
###################################################################

# Set up the directory for the results:
resultsDirectory <- ""
tablesDirectory <- ""

# Read the sample sheet for the experiment:
samplesheet <- read.csv(paste(tablesDirectory, "phenoData.csv", sep = "/"), sep = "," , header = T, stringsAsFactors = F)

#######################################
############### FIGURE1 ###############
#######################################

# Read the beta data for the experiment:
bVals <- read.csv(paste(tablesDirectory, "bVals.txt", sep = "/"), sep = "\t", header = T, stringsAsFactors = F)

# Select the 10000 most variable probes:
bVals2 <- bVals[head(order(-rowVars(as.matrix(bVals))), 10000),]

# Generate heatmap:
annotation_cancer_normal <- data.frame(cancergroup = as.character(samplesheet$Group))
rownames(annotation_cancer_normal) <- colnames(bVals)

pdf(file= paste(resultsDirectory, "heatmap_figure_1.pdf", sep = "/"), paper="a4r", height=21, width=28, onefile=TRUE)
pheatmap(bVals2, cluster_rows = T, cluster_cols = T, color = colorRampPalette(c("white", "slateblue4"))(100), annotation = annotation_cancer_normal, clustering_method = "ward.D2", main = "Heatmap BVals 10000 most variable probes")
dev.off()
