#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of Methylation array data (850K)
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

#install.packages("UpSetR")
library(UpSetR)

# Set up the directory for the results:
resultsDirectory <- ""
tablesDirectory <- ""

AF4 <- read.csv(file = paste(tablesDirectory, "DMPs_filtered_AF4.txt", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
AF9 <- read.csv(file = paste(tablesDirectory,"DMPs_filtered_AF9.txt", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
GERM <- read.csv(file = paste(tablesDirectory,"DMPs_filtered_nonMLL.txt", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
B <- read.csv(file = paste(tablesDirectory,"DMPs_filtered_Bcells.txt", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")

AF4_hyper <- AF4[which(AF4$Methylstat == "hyper"),]
AF4_hypo <- AF4[which(AF4$Methylstat == "hypo"),]
AF9_hyper <- AF9[which(AF9$Methylstat == "hyper"),]
AF9_hypo <- AF9[which(AF9$Methylstat == "hypo"),]
GERM_hyper <- GERM[which(GERM$Methylstat == "hyper"),]
GERM_hypo <- GERM[which(GERM$Methylstat == "hypo"),]
B_hyper <- B[which(B$diff_B_progenitors > 0),]
B_hypo <- B[which(B$diff_B_progenitors < 0),]

listInput <- list(AF4_hyper = rownames(AF4_hyper), AF4_hypo = rownames(AF4_hypo), AF9_hyper = rownames(AF9_hyper), AF9_hypo = rownames(AF9_hypo), GERM_hyper = rownames(GERM_hyper), GERM_hypo = rownames(GERM_hypo), B_hyper = rownames(B_hyper), B_hypo = rownames(B_hypo))

setwd(resultsDirectory)
pdf(file="upsetRplot_DMPs_specific_leukemias_including_Bcells.pdf", paper = "a4r", height = 21, width = 28, onefile = TRUE)
upset(fromList(listInput), order.by = "freq", nsets = 12, number.angles = 45, mainbar.y.label = "Common CpG Probes", sets.x.label = "Number of CpGs", keep.order = TRUE)
dev.off()
