#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of Methylation array data (850K)
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

# Load the required packages:
library("IlluminaHumanMethylationEPICanno.ilm10b2.hg19")
library("ChIPseeker")
library("TxDb.Hsapiens.UCSC.hg19.knownGene")

options("width"=110) #  using R in terminal mode on Linux, making easier the inspection of data sets
###################################################################
#####                       READING DATA                      #####
###################################################################

# Set up the directory for the results:
resultsDirectory <- ""
tablesDirectory <- ""

# Load the datasets:
bVals <- read.csv(paste(tablesDirectory, "bVals.txt", sep = "/"), sep = "\t")
txdb <- TxDb.Hsapiens.UCSC.hg19.knownGene

annotation_EPIC <- as.data.frame(getAnnotation(IlluminaHumanMethylationEPICanno.ilm10b2.hg19))
rownames(annotation_EPIC) <- annotation_EPIC$Name 
annotation_EPIC <- annotation_EPIC[rownames(bVals),]
annotation_EPIC$chr <- as.character(annotation_EPIC$chr)
annotation_EPIC$Name <- as.character(annotation_EPIC$Name)
annotation_EPIC$end <- annotation_EPIC$pos + 1
annotation_EPIC <- annotation_EPIC[order(annotation_EPIC[,"chr"], annotation_EPIC[,"pos"]),]
annotation_EPIC <- annotation_EPIC[,c("chr", "pos", "end", "strand", "Name", "Type", "Probe_rs", "Probe_maf", "Islands_Name", "Relation_to_Island", "DMR", "Phantom4_Enhancers", "Phantom5_Enhancers", "X450k_Enhancer", "HMM_Island", "GencodeCompV12_NAME", "GencodeCompV12_Accession", "GencodeCompV12_Group", "Methyl27_Loci", "Methyl450_Loci")]
write.table(annotation_EPIC, file = paste(tablesDirectory, "annotation_EPIC.txt", sep = "/"), sep = "\t", row.names = F, col.names = T, quote = F)

peak_all <- readPeakFile("annotation_EPIC.txt")
peakAnnoall <- annotatePeak(peak_all, TxDb=txdb, tssRegion=c(-3000, 3000), verbose=FALSE)
all850k <- peakAnnoall@anno@elementMetadata
rownames(all850k) <- as.character(all850k$Name)
all850k$annotation <- gsub("Exon.*", "Exon", all850k$annotation)
all850k$annotation <- gsub("Intron.*", "Intron", all850k$annotation)
all850k$annotation <- gsub("Downstream.*", "Downstream", all850k$annotation)
all850k$annotation <- gsub("Promoter \\(1-2kb\\)", "Distal promoter", all850k$annotation)
all850k$annotation <- gsub("Promoter \\(2-3kb\\)", "Distal promoter", all850k$annotation)

all <- cbind(annotation_EPIC[,c(1:3)], all850k)

write.table(as.data.frame(all), file = paste(tablesDirectory, "annotation_EPIC.txt", sep = "/"), sep = "\t", col.names = T, row.names = F, quote = F)
