#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of Methylation array data (850K)
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

# Load the required packages:
library("genefilter")
library("pheatmap")
library("RColorBrewer")
library("gplots")

options("width"=110) #  using R in terminal mode on Linux, making easier the inspection of data sets
###################################################################
#####                       READING DATA                      #####
###################################################################

# Set up the directory for the results:
resultsDirectory <- ""
tablesDirectory <- ""

###############################################################
###      Generates barplots for loci representation         ###
###############################################################

library(RColorBrewer)
library(ggplot2)
library(tidyr)

AF4_list <- read.csv(paste(tablesDirectory, "List_of_AF4_specific_DMPs.txt", sep = "/"))
AF4 <- read.csv(file = paste(tablesDirectory, "DMPs_filtered_AF4.txt" sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
AF4 <- AF4[which(rownames(AF4) %in% AF4_list$ProbeID),]

AF9_list <- read.csv(paste(tablesDirectory,"List_of_AF9_specific_DMPs.txt", sep = "/"))
AF9 <- read.csv(file = paste(tablesDirectory, "DMPs_filtered_AF9.txt" sep ="/"), header = T, stringsAsFactors = F, sep = "\t")
AF9 <- AF9[which(rownames(AF9) %in% AF9_list$ProbeID),]

nonMLL_list <- read.csv(paste(tablesDirectory,"List_of_nonMLL_specific_DMPs.txt", sep = "/"))
nonMLL<- read.csv(file = paste(tablesDirectory,"DMPs_filtered_nonMLL.txt", sep ="/"), header = T, stringsAsFactors = F, sep = "\t")
nonMLL<- nonMLL[which(rownames(nonMLL) %in% nonMLL_list$ProbeID),]

B <- read.csv(file = paste(tablesDirectory,"DMPs_filtered_Bcells.txt", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")

COMMON_hyper <- read.csv(file = paste(tablesDirectory,"List_of_leukemia_common_hypermethylated_DMPs.txt", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
COMMON_hypo <- read.csv(file = paste(tablesDirectory, "List_of_leukemia_common_hypomethylated_DMPs.txt", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")

AF4_hyper <- AF4[which(AF4$Methylstat == "hyper"),]
AF4_hypo <- AF4[which(AF4$Methylstat == "hypo"),]
AF9_hyper <- AF9[which(AF9$Methylstat == "hyper"),]
AF9_hypo <- AF9[which(AF9$Methylstat == "hypo"),]
nonMLL_hyper<- nonMLL[which(nonMLL$Methylstat == "hyper"),]
nonMLL_hypo <- nonMLL[which(nonMLL$Methylstat == "hypo"),]
B_hyper <- B[which(B$diff_B_progenitors > 0),]
B_hypo <- B[which(B$diff_B_progenitors < 0),]

annotation_EPIC <- read.csv(file = paste(tablesDirectory,"annotation_EPIC.txt", sep = "/"), sep = "\t", header = T, stringsAsFactors = F)
rownames(annotation_EPIC) <- annotation_EPIC$Name
annotation_EPIC$Relation_to_Island <- gsub(pattern = "N_Shelf", replacement = "Shelf", x = annotation_EPIC$Relation_to_Island)
annotation_EPIC$Relation_to_Island <- gsub(pattern = "S_Shelf", replacement = "Shelf", x = annotation_EPIC$Relation_to_Island)
annotation_EPIC$Relation_to_Island <- gsub(pattern = "N_Shore", replacement = "Shore", x = annotation_EPIC$Relation_to_Island)
annotation_EPIC$Relation_to_Island <- gsub(pattern = "S_Shore", replacement = "Shore", x = annotation_EPIC$Relation_to_Island)

# Annotate datasets:
COMMON_hyper <- annotation_EPIC[COMMON_hyper$ProbeID,]
COMMON_hypo <- annotation_EPIC[COMMON_hypo$ProbeID,]
AF4_hyper <- annotation_EPIC[rownames(AF4_hyper),]
AF4_hypo <- annotation_EPIC[rownames(AF4_hypo),]
AF9_hyper <- annotation_EPIC[rownames(AF9_hyper),]
AF9_hypo <- annotation_EPIC[rownames(AF9_hypo),]
nonMLL_hyper<- annotation_EPIC[rownames(nonMLL_hyper),]
nonMLL_hypo <- annotation_EPIC[rownames(nonMLL_hypo),]
B_hyper <- annotation_EPIC[rownames(B_hyper),]
B_hypo <- annotation_EPIC[rownames(B_hypo),]

group_island <- c("Back", "Back", "Back", "Back", "Common", "Common", "Common", "Common", "AF4", "AF4", "AF4", "AF4", "AF9", "AF9", "AF9", "AF9", "nonMLL", "nonMLL", "nonMLL", "nonMLL", "B", "B", "B", "B")
class_island <- c("OpenSea", "Shore", "Shelf", "Island", "OpenSea", "Shore", "Shelf", "Island", "OpenSea", "Shore", "Shelf", "Island", "OpenSea", "Shore", "Shelf", "Island", "OpenSea", "Shore", "Shelf", "Island", "OpenSea", "Shore", "Shelf", "Island")
numbers_island_hyper <- c(length(annotation_EPIC$Relation_to_Island[which(annotation_EPIC$Relation_to_Island == "OpenSea")]), length(annotation_EPIC$Relation_to_Island[which(annotation_EPIC$Relation_to_Island == "Shore")]), length(annotation_EPIC$Relation_to_Island[which(annotation_EPIC$Relation_to_Island == "Shelf")]), length(annotation_EPIC$Relation_to_Island[which(annotation_EPIC$Relation_to_Island == "Island")]),
                          length(COMMON_hyper$Relation_to_Island[which(COMMON_hyper$Relation_to_Island == "OpenSea")]), length(COMMON_hyper$Relation_to_Island[which(COMMON_hyper$Relation_to_Island == "Shore")]), length(COMMON_hyper$Relation_to_Island[which(COMMON_hyper$Relation_to_Island == "Shelf")]), length(COMMON_hyper$Relation_to_Island[which(COMMON_hyper$Relation_to_Island == "Island")]),
                          length(AF4_hyper$Relation_to_Island[which(AF4_hyper$Relation_to_Island == "OpenSea")]), length(AF4_hyper$Relation_to_Island[which(AF4_hyper$Relation_to_Island == "Shore")]), length(AF4_hyper$Relation_to_Island[which(AF4_hyper$Relation_to_Island == "Shelf")]), length(AF4_hyper$Relation_to_Island[which(AF4_hyper$Relation_to_Island == "Island")]),
                          length(AF9_hyper$Relation_to_Island[which(AF9_hyper$Relation_to_Island == "OpenSea")]), length(AF9_hyper$Relation_to_Island[which(AF9_hyper$Relation_to_Island == "Shore")]), length(AF9_hyper$Relation_to_Island[which(AF9_hyper$Relation_to_Island == "Shelf")]), length(AF9_hyper$Relation_to_Island[which(AF9_hyper$Relation_to_Island == "Island")]),
                          length(nonMLL_hyper$Relation_to_Island[which(nonMLL_hyper$Relation_to_Island == "OpenSea")]), length(nonMLL_hyper$Relation_to_Island[which(nonMLL_hyper$Relation_to_Island == "Shore")]), length(nonMLL_hyper$Relation_to_Island[which(nonMLL_hyper$Relation_to_Island == "Shelf")]), length(nonMLL_hyper$Relation_to_Island[which(nonMLL_hyper$Relation_to_Island == "Island")]),
                          length(B_hyper$Relation_to_Island[which(B_hyper$Relation_to_Island == "OpenSea")]), length(B_hyper$Relation_to_Island[which(B_hyper$Relation_to_Island == "Shore")]), length(B_hyper$Relation_to_Island[which(B_hyper$Relation_to_Island == "Shelf")]), length(B_hyper$Relation_to_Island[which(B_hyper$Relation_to_Island == "Island")]))

numbers_island_hypo <- c(length(annotation_EPIC$Relation_to_Island[which(annotation_EPIC$Relation_to_Island == "OpenSea")]), length(annotation_EPIC$Relation_to_Island[which(annotation_EPIC$Relation_to_Island == "Shore")]), length(annotation_EPIC$Relation_to_Island[which(annotation_EPIC$Relation_to_Island == "Shelf")]), length(annotation_EPIC$Relation_to_Island[which(annotation_EPIC$Relation_to_Island == "Island")]),
                          length(COMMON_hypo$Relation_to_Island[which(COMMON_hypo$Relation_to_Island == "OpenSea")]), length(COMMON_hypo$Relation_to_Island[which(COMMON_hypo$Relation_to_Island == "Shore")]), length(COMMON_hypo$Relation_to_Island[which(COMMON_hypo$Relation_to_Island == "Shelf")]), length(COMMON_hypo$Relation_to_Island[which(COMMON_hypo$Relation_to_Island == "Island")]),
                          length(AF4_hypo$Relation_to_Island[which(AF4_hypo$Relation_to_Island == "OpenSea")]), length(AF4_hypo$Relation_to_Island[which(AF4_hypo$Relation_to_Island == "Shore")]), length(AF4_hypo$Relation_to_Island[which(AF4_hypo$Relation_to_Island == "Shelf")]), length(AF4_hypo$Relation_to_Island[which(AF4_hypo$Relation_to_Island == "Island")]),
                          length(AF9_hypo$Relation_to_Island[which(AF9_hypo$Relation_to_Island == "OpenSea")]), length(AF9_hypo$Relation_to_Island[which(AF9_hypo$Relation_to_Island == "Shore")]), length(AF9_hypo$Relation_to_Island[which(AF9_hypo$Relation_to_Island == "Shelf")]), length(AF9_hypo$Relation_to_Island[which(AF9_hypo$Relation_to_Island == "Island")]),
                          length(nonMLL_hypo$Relation_to_Island[which(nonMLL_hypo$Relation_to_Island == "OpenSea")]), length(nonMLL_hypo$Relation_to_Island[which(nonMLL_hypo$Relation_to_Island == "Shore")]), length(nonMLL_hypo$Relation_to_Island[which(nonMLL_hypo$Relation_to_Island == "Shelf")]), length(nonMLL_hypo$Relation_to_Island[which(nonMLL_hypo$Relation_to_Island == "Island")]),
                          length(B_hypo$Relation_to_Island[which(B_hypo$Relation_to_Island == "OpenSea")]), length(B_hypo$Relation_to_Island[which(B_hypo$Relation_to_Island == "Shore")]), length(B_hypo$Relation_to_Island[which(B_hypo$Relation_to_Island == "Shelf")]), length(B_hypo$Relation_to_Island[which(B_hypo$Relation_to_Island == "Island")]))

df_island_hyper <- data.frame(group_island,class_island,numbers_island_hyper)
df_island_hyper$class_island <- factor(df_island_hyper$class_island, levels = c("Island", "Shelf", "Shore", "OpenSea"))
df_island_hyper$group_island <- factor(df_island_hyper$group_island, levels = c("Back", "Common", "AF4", "AF9", "nonMLL", "B")) 

df_island_hypo <- data.frame(group_island,class_island,numbers_island_hypo)
df_island_hypo$class_island <- factor(df_island_hypo$class_island, levels = c("Island", "Shelf", "Shore", "OpenSea"))
df_island_hypo$group_island <- factor(df_island_hypo$group_island, levels = c("Back", "Common", "AF4", "AF9", "nonMLL", "B"))

pdf(file = paste(resultsDirectory, "genomic_distribution_hyper_hypo_filtered_B_from_proB.pdf", sep = "/"), paper = "a4r", height = 21, width = 28, onefile = T)
ggplot(df_island_hyper, aes(x = group_island)) + geom_bar(aes(weight= numbers_island_hyper, fill = class_island), position = 'fill') + scale_fill_manual(values = c("#8B5F65", "#af7e85", "#ce9ca4", "#edc2c9")) + theme_bw() + ggtitle(label = "CpG Hyper distribution CpGI status")
ggplot(df_island_hypo, aes(x = group_island)) + geom_bar(aes(weight= numbers_island_hypo, fill = class_island), position = 'fill') + scale_fill_manual(values = c("#8B5F65", "#af7e85", "#ce9ca4", "#edc2c9")) + theme_bw() + ggtitle(label = "CpG Hypo distribution CpGI status")


###################################################################################

group_region <- c("Back", "Back", "Back", "Back", "Back", "Back", "Back", "Back", "Common", "Common", "Common", "Common", "Common", "Common", "Common", "Common", "AF4", "AF4", "AF4", "AF4", "AF4", "AF4", "AF4", "AF4", "AF9", "AF9", "AF9", "AF9", "AF9", "AF9", "AF9", "AF9", "nonMLL", "nonMLL", "nonMLL", "nonMLL", "nonMLL", "nonMLL", "nonMLL", "nonMLL", "B", "B", "B", "B", "B", "B", "B", "B")
class_region <- c("Distal promoter", "Promoter (<=1kb)", "5' UTR", "Intron", "Exon", "3' UTR", "Downstream", "Distal Intergenic", "Distal promoter", "Promoter (<=1kb)", "5' UTR", "Intron", "Exon", "3' UTR", "Downstream", "Distal Intergenic", "Distal promoter", "Promoter (<=1kb)", "5' UTR", "Intron", "Exon", "3' UTR", "Downstream", "Distal Intergenic", "Distal promoter", "Promoter (<=1kb)", "5' UTR", "Intron", "Exon", "3' UTR", "Downstream", "Distal Intergenic", "Distal promoter", "Promoter (<=1kb)", "5' UTR", "Intron", "Exon", "3' UTR", "Downstream", "Distal Intergenic", "Distal promoter", "Promoter (<=1kb)", "5' UTR", "Intron", "Exon", "3' UTR", "Downstream", "Distal Intergenic")
numbers_region_hyper <- c(length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Distal promoter")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Promoter (<=1kb)")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "5' UTR")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Intron")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Exon")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "3' UTR")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Downstream")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Distal Intergenic")]),
                          length(COMMON_hyper$annotation[which(COMMON_hyper$annotation == "Distal promoter")]), length(COMMON_hyper$annotation[which(COMMON_hyper$annotation == "Promoter (<=1kb)")]), length(COMMON_hyper$annotation[which(COMMON_hyper$annotation == "5' UTR")]), length(COMMON_hyper$annotation[which(COMMON_hyper$annotation == "Intron")]), length(COMMON_hyper$annotation[which(COMMON_hyper$annotation == "Exon")]), length(COMMON_hyper$annotation[which(COMMON_hyper$annotation == "3' UTR")]), length(COMMON_hyper$annotation[which(COMMON_hyper$annotation == "Downstream")]), length(COMMON_hyper$annotation[which(COMMON_hyper$annotation == "Distal Intergenic")]),
                          length(AF4_hyper$annotation[which(AF4_hyper$annotation == "Distal promoter")]), length(AF4_hyper$annotation[which(AF4_hyper$annotation == "Promoter (<=1kb)")]), length(AF4_hyper$annotation[which(AF4_hyper$annotation == "5' UTR")]), length(AF4_hyper$annotation[which(AF4_hyper$annotation == "Intron")]), length(AF4_hyper$annotation[which(AF4_hyper$annotation == "Exon")]), length(AF4_hyper$annotation[which(AF4_hyper$annotation == "3' UTR")]), length(AF4_hyper$annotation[which(AF4_hyper$annotation == "Downstream")]), length(AF4_hyper$annotation[which(AF4_hyper$annotation == "Distal Intergenic")]),
                          length(AF9_hyper$annotation[which(AF9_hyper$annotation == "Distal promoter")]), length(AF9_hyper$annotation[which(AF9_hyper$annotation == "Promoter (<=1kb)")]), length(AF9_hyper$annotation[which(AF9_hyper$annotation == "5' UTR")]), length(AF9_hyper$annotation[which(AF9_hyper$annotation == "Intron")]), length(AF9_hyper$annotation[which(AF9_hyper$annotation == "Exon")]), length(AF9_hyper$annotation[which(AF9_hyper$annotation == "3' UTR")]), length(AF9_hyper$annotation[which(AF9_hyper$annotation == "Downstream")]), length(AF9_hyper$annotation[which(AF9_hyper$annotation == "Distal Intergenic")]),
                          length(nonMLL_hyper$annotation[which(nonMLL_hyper$annotation == "Distal promoter")]), length(nonMLL_hyper$annotation[which(nonMLL_hyper$annotation == "Promoter (<=1kb)")]), length(nonMLL_hyper$annotation[which(nonMLL_hyper$annotation == "5' UTR")]), length(nonMLL_hyper$annotation[which(nonMLL_hyper$annotation == "Intron")]), length(nonMLL_hyper$annotation[which(nonMLL_hyper$annotation == "Exon")]), length(nonMLL_hyper$annotation[which(nonMLL_hyper$annotation == "3' UTR")]), length(nonMLL_hyper$annotation[which(nonMLL_hyper$annotation == "Downstream")]), length(nonMLL_hyper$annotation[which(nonMLL_hyper$annotation == "Distal Intergenic")]),
                          length(B_hyper$annotation[which(B_hyper$annotation == "Distal promoter")]), length(B_hyper$annotation[which(B_hyper$annotation == "Promoter (<=1kb)")]), length(B_hyper$annotation[which(B_hyper$annotation == "5' UTR")]), length(B_hyper$annotation[which(B_hyper$annotation == "Intron")]), length(B_hyper$annotation[which(B_hyper$annotation == "Exon")]), length(B_hyper$annotation[which(B_hyper$annotation == "3' UTR")]), length(B_hyper$annotation[which(B_hyper$annotation == "Downstream")]), length(B_hyper$annotation[which(B_hyper$annotation == "Distal Intergenic")]))
                          
numbers_region_hypo <- c(length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Distal promoter")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Promoter (<=1kb)")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "5' UTR")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Intron")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Exon")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "3' UTR")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Downstream")]), length(annotation_EPIC$annotation[which(annotation_EPIC$annotation == "Distal Intergenic")]),
                          length(COMMON_hypo$annotation[which(COMMON_hypo$annotation == "Distal promoter")]), length(COMMON_hypo$annotation[which(COMMON_hypo$annotation == "Promoter (<=1kb)")]), length(COMMON_hypo$annotation[which(COMMON_hypo$annotation == "5' UTR")]), length(COMMON_hypo$annotation[which(COMMON_hypo$annotation == "Intron")]), length(COMMON_hypo$annotation[which(COMMON_hypo$annotation == "Exon")]), length(COMMON_hypo$annotation[which(COMMON_hypo$annotation == "3' UTR")]), length(COMMON_hypo$annotation[which(COMMON_hypo$annotation == "Downstream")]), length(COMMON_hypo$annotation[which(COMMON_hypo$annotation == "Distal Intergenic")]),
                          length(AF4_hypo$annotation[which(AF4_hypo$annotation == "Distal promoter")]), length(AF4_hypo$annotation[which(AF4_hypo$annotation == "Promoter (<=1kb)")]), length(AF4_hypo$annotation[which(AF4_hypo$annotation == "5' UTR")]), length(AF4_hypo$annotation[which(AF4_hypo$annotation == "Intron")]), length(AF4_hypo$annotation[which(AF4_hypo$annotation == "Exon")]), length(AF4_hypo$annotation[which(AF4_hypo$annotation == "3' UTR")]), length(AF4_hypo$annotation[which(AF4_hypo$annotation == "Downstream")]), length(AF4_hypo$annotation[which(AF4_hypo$annotation == "Distal Intergenic")]),
                          length(AF9_hypo$annotation[which(AF9_hypo$annotation == "Distal promoter")]), length(AF9_hypo$annotation[which(AF9_hypo$annotation == "Promoter (<=1kb)")]), length(AF9_hypo$annotation[which(AF9_hypo$annotation == "5' UTR")]), length(AF9_hypo$annotation[which(AF9_hypo$annotation == "Intron")]), length(AF9_hypo$annotation[which(AF9_hypo$annotation == "Exon")]), length(AF9_hypo$annotation[which(AF9_hypo$annotation == "3' UTR")]), length(AF9_hypo$annotation[which(AF9_hypo$annotation == "Downstream")]), length(AF9_hypo$annotation[which(AF9_hypo$annotation == "Distal Intergenic")]),
                          length(nonMLL_hypo$annotation[which(nonMLL_hypo$annotation == "Distal promoter")]), length(nonMLL_hypo$annotation[which(nonMLL_hypo$annotation == "Promoter (<=1kb)")]), length(nonMLL_hypo$annotation[which(nonMLL_hypo$annotation == "5' UTR")]), length(nonMLL_hypo$annotation[which(nonMLL_hypo$annotation == "Intron")]), length(nonMLL_hypo$annotation[which(nonMLL_hypo$annotation == "Exon")]), length(nonMLL_hypo$annotation[which(nonMLL_hypo$annotation == "3' UTR")]), length(nonMLL_hypo$annotation[which(nonMLL_hypo$annotation == "Downstream")]), length(nonMLL_hypo$annotation[which(nonMLL_hypo$annotation == "Distal Intergenic")]),
                          length(B_hypo$annotation[which(B_hypo$annotation == "Distal promoter")]), length(B_hypo$annotation[which(B_hypo$annotation == "Promoter (<=1kb)")]), length(B_hypo$annotation[which(B_hypo$annotation == "5' UTR")]), length(B_hypo$annotation[which(B_hypo$annotation == "Intron")]), length(B_hypo$annotation[which(B_hypo$annotation == "Exon")]), length(B_hypo$annotation[which(B_hypo$annotation == "3' UTR")]), length(B_hypo$annotation[which(B_hypo$annotation == "Downstream")]), length(B_hypo$annotation[which(B_hypo$annotation == "Distal Intergenic")]))

df_region_hyper <- data.frame(group_region,class_region,numbers_region_hyper)
df_region_hyper$class_region <- factor(df_region_hyper$class_region, levels = c("Distal promoter", "Promoter (<=1kb)", "5' UTR", "Intron", "Exon", "3' UTR", "Downstream", "Distal Intergenic")) 
df_region_hyper$group_region <- factor(df_region_hyper$group_region, levels = c("Back", "Common", "AF4", "AF9", "nonMLL", "B")) 

df_region_hypo <- data.frame(group_region,class_region,numbers_region_hypo)
df_region_hypo$class_region <- factor(df_region_hypo$class_region, levels = c("Distal promoter", "Promoter (<=1kb)", "5' UTR", "Intron", "Exon", "3' UTR", "Downstream", "Distal Intergenic"))  
df_region_hypo$group_region <- factor(df_region_hypo$group_region, levels = c("Back", "Common", "AF4", "AF9", "nonMLL", "B")) 

ggplot(df_region_hyper, aes(x = group_region)) + geom_bar(aes(weight = numbers_region_hyper, fill = class_region), position = 'fill') + scale_fill_manual(values = c("#535e6b", "#6e7a89", "#828fa0", "#96a4b7", "#a7b5c9", "#bcc8d8", "#dce1e8", "#eaedef")) + theme_bw() + ggtitle(label = "CpG Hyper distribution Region status")
ggplot(df_region_hypo, aes(x = group_region)) + geom_bar(aes(weight = numbers_region_hypo, fill = class_region), position = 'fill') + scale_fill_manual(values = c("#535e6b", "#6e7a89", "#828fa0", "#96a4b7", "#a7b5c9", "#bcc8d8", "#dce1e8", "#eaedef")) + theme_bw() + ggtitle(label = "CpG Hypo distribution Region status")

dev.off()

colnames(COMMON_hyper)[2] <- "start"
colnames(COMMON_hypo)[2] <- "start"
colnames(AF4_hyper)[2] <- "start"
colnames(AF4_hypo)[2] <- "start"
colnames(AF9_hyper)[2] <- "start"
colnames(AF9_hypo)[2] <- "start"
colnames(nonMLL_hyper)[2] <- "start"
colnames(nonMLL_hypo)[2] <- "start"
colnames(B_hyper)[2] <- "start"
colnames(B_hypo)[2] <- "start"

write.table(COMMON_hyper, file = paste(tablesDirectory, "annotation_COMMON_hyper_probes.txt", sep = "/"), sep = "\t", col.names = T, row.names = F, quote = F)
write.table(COMMON_hypo, file = paste(tablesDirectory,"annotation_COMMON_hypo_probes.txt", sep = "/"), sep = "\t", col.names = T, row.names = F, quote = F)
write.table(AF4_hyper, file = paste(tablesDirectory,"annotation_AF4_hyper_probes.txt", sep = "/"), sep = "\t", col.names = T, row.names = F, quote = F)
write.table(AF4_hypo, file = paste(tablesDirectory,"annotation_AF4_hypo_probes.txt", sep = "/"), sep = "\t", col.names = T, row.names = F, quote = F)
write.table(AF9_hyper, file = paste(tablesDirectory,"annotation_AF9_hyper_probes.txt", sep = "/"), sep = "\t", col.names = T, row.names = F, quote = F)
write.table(AF9_hypo, file = paste(tablesDirectory,"annotation_AF9_hypo_probes.txt", sep = "/"), sep = "\t", col.names = T, row.names = F, quote = F)
write.table(nonMLL_hyper, file = paste(tablesDirectory,"annotation_nonMLL_hyper_probes.txt", sep = "/"), sep = "\t", col.names = T, row.names = F, quote = F)
write.table(nonMLL_hypo, file = paste(tablesDirectory,"annotation_nonMLL_hypo_probes.txt", sep = "/"), sep = "\t", col.names = T, row.names = F, quote = F)
write.table(B_hyper, file = paste(tablesDirectory,"annotation_B_hyper_probes.txt", sep = "/"), sep = "\t", col.names = T, row.names = F, quote = F)
write.table(B_hypo, file = paste(tablesDirectory,"annotation_B_hypo_probes.txt", sep = "/"), sep = "\t", col.names = T, row.names = F, quote = F)
