#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of Methylation array data (850K)
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

# Repeat this step as many times as annotation files present for the following datasets (COMMON, AF4, AF9, nonMLL, B)

# Load the required packages:
library("magrittr")
library("dplyr")
library("tidyr")
library("ggplot2")
library("ChIPseeker")
library("TxDb.Hsapiens.UCSC.hg19.knownGene")
library("clusterProfiler")
library("ReactomePA")
library("VennDiagram")
library("reshape2")
library("pheatmap")
library("RColorBrewer")
library("LOLA")

# Set up the directory for the results:
resultsDirectory <- ""
tablesDirectory <- ""
databasesDirectory <- ""

# Load the datasets to establish to plot the pie charts:
hypermethylation <- read.csv(file = paste(tablesDirectory, "annotation_COMMON_hyper_probes.txt", sep = "/"), sep = "\t", stringsAsFactors = F)
hypomethylation <- read.csv(file = paste(tablesDirectory, "annotation_COMMON_hypo_probes.txt", sep = "/"), sep = "\t", stringsAsFactors = F)

# Generate Granges files for the hyper and the hypomethylated probes:
hypermethylationprobes <- allprobes_cpg[which(allprobes_cpg$Name %in% hypermethylation$Name),]
hypermethylationprobes <- hypermethylationprobes[order(hypermethylationprobes[,"chr"], hypermethylationprobes[,"start"]),]
regionSethyper <- makeGRangesFromDataFrame(hypermethylationprobes, ignore.strand = TRUE, seqnames.field = "chr", start.field = "start", end.field = "end")
hypomethylationprobes <- allprobes_cpg[which(allprobes_cpg$Name %in% hypomethylation$Name),]
hypomethylationprobes <- hypomethylationprobes[order(hypomethylationprobes[,"chr"], hypomethylationprobes[,"start"]),]
regionSethypo <- makeGRangesFromDataFrame(hypomethylationprobes, ignore.strand = TRUE, seqnames.field = "chr", start.field = "start", end.field = "end")
allprobes_cpg <- allprobes_cpg[order(allprobes_cpg[,"chr"], allprobes_cpg[,"start"]),]
regionSetAll = makeGRangesFromDataFrame(allprobes_cpg, ignore.strand = TRUE, seqnames.field = "chr", start.field = "start", end.field = "end")

# Load the databases with the Regions of Interest:
regionDB <- loadRegionDB(dbLocation = paste(databasesDirectory, "hg19", sep = "/"), collections = "GTRD_tfbs")

# Generate tables from lists (probes)
userSets = GRangesList(hyper = regionSethyper, hypo = regionSethypo)

locResults_hyper = runLOLA(userSets[1], regionSetAll, regionDB, cores=4)
locResults_hypo = runLOLA(userSets[2], regionSetAll, regionDB, cores=4)

write.table(locResults_hyper, file = paste(tablesDirectory,"enrichment_GTRD_tfbs_hyper_COMMON_leukemia.txt", sep = "/"), quote = F, col.names = T, row.names = F, sep = "\t")
write.table(locResults_hypo, file = paste(tablesDirectory,"enrichment_GTRD_tfbs_hypo_COMMON_leukemia.txt", sep = "/"), quote = F, col.names = T, row.names = F, sep = "\t")

