#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of WGBS methylation changes in ALL subtypes
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

# Load the required packages:
library("genefilter")
library("FactoMineR")
library("gplots")
library("cluster")
library("gridExtra")
library("factoextra")
library("RColorBrewer")
library("rgl")
library("pheatmap")
library("ggplot2")

# Set up the directory for the results:
tablesDirectory <- ""
resultsDirectory <- ""

# Load the data:
bVals <- read.table(file = paste(tablesDirectory, "bVals.txt", sep = "/"), header = T, sep = "\t")
bVals <- bVals[, c("X4.23", "X4.28", "X9.11", "X9.12", "M.16", "M.21", "C.1", "C.2")]
annotationEPIC <- read.csv(file = paste(tablesDirectory, "annotation_EPIC.txt", sep = "/"), header = T, sep = "\t")
rownames(annotationEPIC) <- annotationEPIC$Name
#annotationEPIC$pos2 <- annotationEPIC$pos + 1
annotationEPIC$strand <- as.character(annotationEPIC$strand)
annotationEPIC$strand[which(annotationEPIC$strand == "+")] <- "F"
annotationEPIC$strand[which(annotationEPIC$strand == "-")] <- "R"
annotationEPIC$coordinates <- paste(annotationEPIC$chr, ".", annotationEPIC$pos, "_", annotationEPIC$strand, sep = "")
annotationEPIC$coordinates <- gsub(pattern = "chr", replacement = "", x = annotationEPIC$coordinates)
annotationEPIC <- annotationEPIC[rownames(bVals),]
rownames(bVals) <- annotationEPIC$coordinates

bVals2 <- read.table(file = paste(tablesDirectory, "bVals.txt", sep = "/"), header = T, sep = "\t")
bVals2 <- bVals2[, c("X4.23", "X4.28", "X9.11", "X9.12", "M.16", "M.21", "C.1", "C.2")]
annotationEPIC2 <- read.csv(file = paste(tablesDirectory, "annotation_EPIC.txt", sep = "/"), header = T, sep = "\t")
rownames(annotationEPIC2) <- annotationEPIC2$Name
annotationEPIC2$pos2 <- annotationEPIC2$pos + 1
annotationEPIC2$coordinates <- paste(annotationEPIC2$chr, ".", annotationEPIC2$pos2, sep = "")
annotationEPIC2$coordinates <- gsub(pattern = "chr", replacement = "", x = annotationEPIC2$coordinates)
annotationEPIC2 <- annotationEPIC2[rownames(bVals2),]
rownames(bVals2) <- annotationEPIC2$coordinates

bVals3 <- read.table(file = paste(tablesDirectory, "bVals.txt", sep = "/"), header = T, sep = "\t")
bVals3 <- bVals3[, c("X4.23", "X4.28", "X9.11", "X9.12", "M.16", "M.21", "C.1", "C.2")]
annotationEPIC2 <- read.csv(file = paste(tablesDirectory, "annotation_EPIC.txt", sep = "/"), header = T, sep = "\t")
rownames(annotationEPIC2) <- annotationEPIC2$Name
annotationEPIC2$pos2 <- annotationEPIC2$pos + 1
annotationEPIC2$coordinates <- paste(annotationEPIC2$chr, ".", annotationEPIC2$pos2, sep = "")
annotationEPIC2$coordinates <- gsub(pattern = "chr", replacement = "", x = annotationEPIC2$coordinates)
annotationEPIC2 <- annotationEPIC2[rownames(bVals3),]
rownames(bVals3) <- annotationEPIC2$coordinates

bVals4 <- rbind(bVals, bVals2, bVals3)

MLL_AF4_1 <- read.csv(file = paste(tablesDirectory, "WGBS_analyses/MLL-AF4_1_CpG.txt", sep = "/"), header = T, sep = "\t")
rownames(MLL_AF4_1) <- paste(MLL_AF4_1$chrBase, MLL_AF4_1$strand, sep = "_")
bVals_AF4_1 <- bVals[which(rownames(bVals4) %in% rownames(MLL_AF4_1)),]
MLL_AF4_1_filtered <- MLL_AF4_1[rownames(bVals_AF4_1),]
MLL_AF4_1_filtered$freqC <- MLL_AF4_1_filtered$freqC / 100

MLL_AF4_2 <- read.csv(file = paste(tablesDirectory, "WGBS_analyses/MLL-AF4_2_CpG.txt", sep = "/"), header = T, sep = "\t")
rownames(MLL_AF4_2) <- MLL_AF4_2$chrBase
bVals_AF4_2 <- bVals[which(rownames(bVals4) %in% rownames(MLL_AF4_2)),]
MLL_AF4_2_filtered <- MLL_AF4_2[rownames(bVals_AF4_2),]
MLL_AF4_2_filtered$freqC <- MLL_AF4_2_filtered$freqC / 100

MLL_AF9_1 <- read.csv(file = paste(tablesDirectory, "WGBS_analyses/MLL-AF9_1_CpG.txt", sep = "/"), header = T, sep = "\t")
rownames(MLL_AF9_1) <- MLL_AF9_1$chrBase
bVals_AF9_1 <- bVals[which(rownames(bVals4) %in% rownames(MLL_AF9_1)),]
MLL_AF9_1_filtered <- MLL_AF9_1[rownames(bVals_AF9_1),]
MLL_AF9_1_filtered$freqC <- MLL_AF9_1_filtered$freqC / 100

MLL_AF9_2 <- read.csv(file = paste(tablesDirectory, "WGBS_analyses/MLL-AF9_2_CpG.txt", sep = "/"), header = T, sep = "\t")
rownames(MLL_AF9_2) <- MLL_AF9_2$chrBase
bVals_AF9_2 <- bVals[which(rownames(bVals4) %in% rownames(MLL_AF9_2)),]
MLL_AF9_2_filtered <- MLL_AF9_2[rownames(bVals_AF9_2),]
MLL_AF9_2_filtered$freqC <- MLL_AF9_2_filtered$freqC / 100

non_MLL_1 <- read.csv(file = paste(tablesDirectory, "WGBS_analyses/non-MLL-1_CpG.txt", sep = "/"), header = T, sep = "\t")
rownames(non_MLL_1) <- non_MLL_1$chrBase
bVals_non_MLL_1 <- bVals[which(rownames(bVals4) %in% rownames(non_MLL_1)),]
non_MLL_1_filtered <- non_MLL_1[rownames(bVals_non_MLL_1),]
non_MLL_1_filtered$freqC <- non_MLL_1_filtered$freqC / 100

non_MLL_2 <- read.csv(file = paste(tablesDirectory, "WGBS_analyses/non-MLL-2_CpG.txt", sep = "/"), header = T, sep = "\t")
rownames(non_MLL_2) <- non_MLL_2$chrBase
bVals_non_MLL_2 <- bVals[which(rownames(bVals4) %in% rownames(non_MLL_2)),]
non_MLL_2_filtered <- non_MLL_2[rownames(bVals_non_MLL_2),]
non_MLL_2_filtered$freqC <- non_MLL_2_filtered$freqC / 100

BCP_1 <- read.csv(file = paste(tablesDirectory, "WGBS_analyses/BCP_1_CpG.txt", sep = "/"), header = T, sep = "\t")
rownames(BCP_1) <- BCP_1$chrBase
bVals_BCP_1 <- bVals[which(rownames(bVals4) %in% rownames(BCP_1)),]
BCP_1_filtered <- BCP_1[rownames(bVals_BCP_1),]
BCP_1_filtered$freqC <- BCP_1_filtered$freqC / 100

BCP_2 <- read.csv(file = paste(tablesDirectory, "WGBS_analyses/BCP_2_CpG.txt", sep = "/"), header = T, sep = "\t")
rownames(BCP_2) <- BCP_2$chrBase
bVals_BCP_2 <- bVals[which(rownames(bVals4) %in% rownames(BCP_2)),]
BCP_2_filtered <- BCP_2[rownames(bVals_BCP_2),]
BCP_2_filtered$freqC <- BCP_2_filtered$freqC / 100

# Generate scatterplot to inspect differences between Arrays and the rest of conditions:
pdf(file=paste(resultsDirectory, "Scatterplots_Array_vs_WGBS.pdf", sep = "/"), height=28, width=21, onefile=TRUE)
par(pty="s", mfrow=c(4,2))
smoothScatter(x=bVals_AF4_1[,"X4.23"], y=MLL_AF4_1_filtered[,"freqC"], xlab="Beta values Array", ylab="Beta values WGBS", main="smooth scatter plot MLL-AF4 4.23")
correlation_AF4_1 <- cor(MLL_AF4_1_filtered[,"freqC"], bVals_AF4_1[,"X4.23"])
model_AF4_1 <- lm(MLL_AF4_1_filtered[,"freqC"] ~ bVals_AF4_1[,"X4.23"])
abline(v = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(v = 0.75, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.75, untf = FALSE, col = "darkgrey", lty = 2, lwd=2)
abline(model_AF4_1, col = "red", lty = 2, lwd=3)
text(0.5, 0.5, paste("n = ", nrow(bVals_AF4_1), sep = ""))
text(0.5, 0.4, paste("cor = ", correlation_AF4_1, sep = ""))

smoothScatter(x=bVals_AF4_2[,"X4.28"], y=MLL_AF4_2_filtered[,"freqC"], xlab="Beta values Array", ylab="Beta values WGBS", main="smooth scatter plot MLL-AF4 4.28")
correlation_AF4_2 <- cor(MLL_AF4_2_filtered[,"freqC"], bVals_AF4_2[,"X4.28"])
model_AF4_2 <- lm(MLL_AF4_2_filtered[,"freqC"] ~ bVals_AF4_2[,"X4.28"])
abline(v = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(v = 0.75, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.75, untf = FALSE, col = "darkgrey", lty = 2, lwd=2)
abline(model_AF4_2, col = "red", lty = 2, lwd=3)
text(0.5, 0.5, paste("n = ", nrow(bVals_AF4_2), sep = ""))
text(0.5, 0.4, paste("cor = ", correlation_AF4_2, sep = ""))

smoothScatter(x=bVals_AF9_1[,"X9.11"], y=MLL_AF9_1_filtered[,"freqC"], xlab="Beta values Array", ylab="Beta values WGBS", main="smooth scatter plot MLL-AF9 9.11")
correlation_AF9_1 <- cor(MLL_AF9_1_filtered[,"freqC"], bVals_AF9_1[,"X9.11"])
model_AF9_1 <- lm(MLL_AF9_1_filtered[,"freqC"] ~ bVals_AF9_1[,"X9.11"])
abline(v = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(v = 0.75, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.75, untf = FALSE, col = "darkgrey", lty = 2, lwd=2)
abline(model_AF9_1, col = "red", lty = 2, lwd=3)
text(0.5, 0.5, paste("n = ", nrow(bVals_AF9_1), sep = ""))
text(0.5, 0.4, paste("cor = ", correlation_AF9_1, sep = ""))

smoothScatter(x=bVals_AF9_2[,"X9.12"], y=MLL_AF9_2_filtered[,"freqC"], xlab="Beta values Array", ylab="Beta values WGBS", main="smooth scatter plot MLL-AF9 9.12")
correlation_AF9_2 <- cor(MLL_AF9_2_filtered[,"freqC"], bVals_AF9_2[,"X9.12"])
model_AF9_2 <- lm(MLL_AF9_2_filtered[,"freqC"] ~ bVals_AF9_2[,"X9.12"])
abline(v = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(v = 0.75, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.75, untf = FALSE, col = "darkgrey", lty = 2, lwd=2)
abline(model_AF9_2, col = "red", lty = 2, lwd=3)
text(0.5, 0.5, paste("n = ", nrow(bVals_AF9_2), sep = ""))
text(0.5, 0.4, paste("cor = ", correlation_AF9_2, sep = ""))

smoothScatter(x=bVals_non_MLL_1[,"X9.11"], y=non_MLL_1_filtered[,"freqC"], xlab="Beta values Array", ylab="Beta values WGBS", main="smooth scatter plot non-MLL M.16")
correlation_non_MLL_1 <- cor(non_MLL_1_filtered[,"freqC"], bVals_non_MLL_1[,"M.16"])
model_non_MLL_1 <- lm(non_MLL_1_filtered[,"freqC"] ~ bVals_non_MLL_1[,"M.16"])
abline(v = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(v = 0.75, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.75, untf = FALSE, col = "darkgrey", lty = 2, lwd=2)
abline(model_non_MLL_1, col = "red", lty = 2, lwd=3)
text(0.5, 0.5, paste("n = ", nrow(bVals_non_MLL_1), sep = ""))
text(0.5, 0.4, paste("cor = ", correlation_non_MLL_1, sep = ""))

smoothScatter(x=bVals_non_MLL_2[,"X9.12"], y=non_MLL_2_filtered[,"freqC"], xlab="Beta values Array", ylab="Beta values WGBS", main="smooth scatter plot non-MLL M.21")
correlation_non_MLL_2 <- cor(non_MLL_2_filtered[,"freqC"], bVals_non_MLL_2[,"M.21"])
model_non_MLL_2 <- lm(non_MLL_2_filtered[,"freqC"] ~ bVals_non_MLL_2[,"M.21"])
abline(v = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(v = 0.75, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.75, untf = FALSE, col = "darkgrey", lty = 2, lwd=2)
abline(model_non_MLL_2, col = "red", lty = 2, lwd=3)
text(0.5, 0.5, paste("n = ", nrow(bVals_non_MLL_2), sep = ""))
text(0.5, 0.4, paste("cor = ", correlation_non_MLL_2, sep = ""))

smoothScatter(x=bVals_BCP_1[,"X9.11"], y=BCP_1_filtered[,"freqC"], xlab="Beta values Array", ylab="Beta values WGBS", main="smooth scatter plot BCP_ 1")
correlation_BCP_1 <- cor(BCP_1_filtered[,"freqC"], bVals_BCP_1[,"C.1"])
model_BCP_1 <- lm(BCP_1_filtered[,"freqC"] ~ bVals_BCP_1[,"C.1"])
abline(v = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(v = 0.75, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.75, untf = FALSE, col = "darkgrey", lty = 2, lwd=2)
abline(model_BCP_1, col = "red", lty = 2, lwd=3)
text(0.5, 0.5, paste("n = ", nrow(bVals_BCP_1), sep = ""))
text(0.5, 0.4, paste("cor = ", correlation_BCP_1, sep = ""))

smoothScatter(x=bVals_BCP_2[,"X9.12"], y=BCP_2_filtered[,"freqC"], xlab="Beta values Array", ylab="Beta values WGBS", main="smooth scatter plot BCP_ 2")
correlation_BCP_2 <- cor(BCP_2_filtered[,"freqC"], bVals_BCP_2[,"C.2"])
model_BCP_2 <- lm(BCP_2_filtered[,"freqC"] ~ bVals_BCP_2[,"C.2"])
abline(v = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(v = 0.75, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.25, untf = FALSE, col = "darkgrey", lty = 2); abline(h = 0.75, untf = FALSE, col = "darkgrey", lty = 2, lwd=2)
abline(model_BCP_2, col = "red", lty = 2, lwd=3)
text(0.5, 0.5, paste("n = ", nrow(bVals_BCP_2), sep = ""))
text(0.5, 0.4, paste("cor = ", correlation_BCP_2, sep = ""))

dev.off()
