#############################################################################
### PROJECT: Differential methylation analysis of Infant leukemias
### and differentiated blood cells with 850k arrays
###
### Script for the analysis of Methylation array data (850K)
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

# Set up the directory for the results:
tablesDirectory <- ""
resultsDirectory <- ""

library(ggplot2)
library(reshape)
library(RColorBrewer)
library(gridExtra)
theme_set(theme_bw())

# Load and process the txt files (should be sorted before proceed with this step):
CpGs <- read.table(file = paste(tablesDirectory, "bVals.txt", sep = "/"), header = T, sep = "\t")
CpGs <- CpGs[, c("X4.23", "X4.28", "X9.11", "X9.12", "M.16", "M.21", "C.1", "C.2")]

# Tune up the tables:
bVals_CpGs <- melt(CpGs)
bVals_CpGs <- bVals_CpGs[complete.cases(bVals_CpGs),]

# generate boxplots:
colors_cells <- t(data.frame(X4.23 = "#D53E4F", X4.28 = "#D53E4F", X9.11 = "#2eaa6c", X9.12 = "#2eaa6c", M.16 = "#e8db4c", M.21 = "#e8db4c", C.1 = "#3288BD", C.2 = "#3288BD"))
colnames(colors_cells) <- "color"

pdf("violinplots_all_CpGs_EPIC.pdf", paper="a4r", height=12, width=16, onefile=TRUE)
a <- ggplot(bVals_CpGs, aes(variable, value, fill = as.factor(variable)))
a + geom_violin(width=1) + geom_boxplot(width=0.1, outlier.shape = NA) + theme(axis.text.x = element_text(angle = 65, vjust = 0.6), legend.position = "none") + labs(title = "DNA methylation CpGs", x = "cells", y = "B-Value") + scale_fill_manual(values = c("#D53E4F", "#D53E4F", "#2eaa6c", "#2eaa6c", "#e8db4c", "#e8db4c", "#3288BD", "#3288BD"))
dev.off()
