#############################################################################
### PROJECT: Differential expression analysis of Infant leukemias
### and differentiated blood cells with RNAseq data
###
### Script for the calculation of correlations
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

resultsDirectory <- ""
tablesDirectory <- ""

# Load the data:
phenoData <- read.csv(file = paste(tablesDirectory, "phenoData2.csv", sep = "/"), header = T, sep = ",", stringsAsFactors = F)
rownames(phenoData) <- phenoData$COD_ANT
bValues <- read.table(file = paste(tablesDirectory, "bVals.txt", sep = "/"), header = T, sep = "\t")
colnames(bValues) <- phenoData$COD_ANT
AF4_probes <- read.csv(file = paste(tablesDirectory, "DMPs_filtered_AF4.txt", sep = "/"), header = T, sep = "\t", stringsAsFactors = F)
AF9_probes <- read.csv(file = paste(tablesDirectory, "DMPs_filtered_AF9.txt", sep = "/"), header = T, sep = "\t", stringsAsFactors = F)
GERM_probes <- read.csv(file = paste(tablesDirectory, "DMPs_filtered_GERMLINE.txt", sep = "/"), header = T, sep = "\t", stringsAsFactors = F)
genes_all <- read.table(file = "RSEM_RNAseq_genes_FPKM_matrix.tsv", header = T, sep = "\t")
colnames(genes_all)[43:47] <- c("Normal_1", "Normal_2", "Normal_3", "Normal_4", "Normal_5")
genes_all$MA4_01 <- as.numeric(as.character(genes_all$MA4_01))
genes_all <- genes_all[!duplicated(genes_all$ENSG_name), ]
genes_all <- genes_all[complete.cases(genes_all),]
rownames(genes_all) <- genes_all$ENSG_name
genes_all <- genes_all[,c(-1,-2)]
genes_all <- genes_all + 1
genes_all <- log(genes_all,2)
genes_all <- genes_all[is.finite(rowSums(genes_all)),]
keep <- rowSums(genes_all) >= 20
genes_all <- genes_all[keep,]
genes_all <- genes_all[complete.cases(genes_all),]

# Select Progenitors and B cells:
phenoData_filtered_AF4 <- phenoData[which(phenoData$Group == "B-PROGENITORS" & phenoData$RNA_expression == "YES" | phenoData$Group == "MLL-AF4" & phenoData$RNA_expression == "YES"),]
bVals_filtered_AF4 <- bValues[rownames(AF4_probes),phenoData_filtered_AF4$COD_ANT]
genes_all_filtered_AF4 <- genes_all[,phenoData_filtered_AF4$COD_ANT]

phenoData_filtered_AF9 <- phenoData[which(phenoData$Group == "B-PROGENITORS" & phenoData$RNA_expression == "YES" | phenoData$Group == "MLL-AF9" & phenoData$RNA_expression == "YES"),]
bVals_filtered_AF9 <- bValues[rownames(AF9_probes),phenoData_filtered_AF9$COD_ANT]
genes_all_filtered_AF9 <- genes_all[,phenoData_filtered_AF9$COD_ANT]

phenoData_filtered_GERM <- phenoData[which(phenoData$Group == "B-PROGENITORS" & phenoData$RNA_expression == "YES" | phenoData$Group == "MLL GERMLINE" & phenoData$RNA_expression == "YES"),]
bVals_filtered_GERM <- bValues[rownames(GERM_probes),phenoData_filtered_GERM$COD_ANT]
genes_all_filtered_GERM <- genes_all[,phenoData_filtered_GERM$COD_ANT]

# Load the old tables:
COMMON_pairs_hyper <- read.csv("hyper_pairs_COMMON_new.txt", sep = "\t", stringsAsFactors = F)
COMMON_pairs_hypo <- read.csv("hypo_pairs_COMMON_new.txt", sep = "\t", stringsAsFactors = F)

AF4_pairs_hyper <- read.csv("hyper_pairs_AF4_new.txt", sep = "\t", stringsAsFactors = F)
AF4_pairs_hypo <- read.csv("hypo_pairs_AF4_new.txt", sep = "\t", stringsAsFactors = F)

AF9_pairs_hyper <- read.csv("hyper_pairs_AF9_new.txt", sep = "\t", stringsAsFactors = F)
AF9_pairs_hypo <- read.csv("hypo_pairs_AF9_new.txt", sep = "\t", stringsAsFactors = F)

GERM_pairs_hyper <- read.csv("hyper_pairs_GERM_new.txt", sep = "\t", stringsAsFactors = F)
GERM_pairs_hypo <- read.csv("hypo_pairs_GERM_new.txt", sep = "\t", stringsAsFactors = F)

COMMON_pairs_hyper$Dir_leukemia <- "hyper"
COMMON_pairs_hypo$Dir_leukemia <- "hypo"

AF4_pairs_hyper$Dir_leukemia <- "hyper"
AF4_pairs_hypo$Dir_leukemia <- "hypo"

AF9_pairs_hyper$Dir_leukemia <- "hyper"
AF9_pairs_hypo$Dir_leukemia <- "hypo"

GERM_pairs_hyper$Dir_leukemia <- "hyper"
GERM_pairs_hypo$Dir_leukemia <- "hypo"

COMMON_pairs <- rbind(COMMON_pairs_hyper, COMMON_pairs_hypo)
AF4_pairs <- rbind(AF4_pairs_hyper, AF4_pairs_hypo)
AF9_pairs <- rbind(AF9_pairs_hyper, AF9_pairs_hypo)
GERM_pairs <- rbind(GERM_pairs_hyper, GERM_pairs_hypo)

COMMON_probes_vector <- c(COMMON_pairs$Probe)
phenoData_filtered_COMMON <- phenoData[which(phenoData$Group == "B-PROGENITORS" & phenoData$RNA_expression == "YES" | phenoData$Group == "MLL-AF4" & phenoData$RNA_expression == "YES" | phenoData$Group == "MLL-AF9" & phenoData$RNA_expression == "YES" | phenoData$Group == "MLL GERMLINE" & phenoData$RNA_expression == "YES"),]
bVals_filtered_COMMON <- bValues[COMMON_probes_vector,phenoData_filtered_COMMON$COD_ANT]
genes_all_filtered_COMMON <- genes_all[,phenoData_filtered_COMMON$COD_ANT]

# Annotate the LogFC and the adj.P.val of the CpGs:
COMMON_probes <- rbind(AF4_probes, AF9_probes, GERM_probes)
COMMON_pairs$LogFC_meth <- COMMON_probes[match(COMMON_pairs$Probe, rownames(COMMON_probes)), 1]
COMMON_pairs$Adj.P.val_meth <- COMMON_probes[match(COMMON_pairs$Probe, rownames(COMMON_probes)), 5]

AF4_pairs$LogFC_meth <- AF4_probes[match(AF4_pairs$Probe, rownames(AF4_probes)), 1]
AF4_pairs$Adj.P.val_meth <- AF4_probes[match(AF4_pairs$Probe, rownames(AF4_probes)), 5]

AF9_pairs$LogFC_meth <- AF9_probes[match(AF9_pairs$Probe, rownames(AF9_probes)), 1]
AF9_pairs$Adj.P.val_meth <- AF9_probes[match(AF9_pairs$Probe, rownames(AF9_probes)), 5]

GERM_pairs$LogFC_meth <- GERM_probes[match(GERM_pairs$Probe, rownames(GERM_probes)), 1]
GERM_pairs$Adj.P.val_meth <- GERM_probes[match(GERM_pairs$Probe, rownames(GERM_probes)), 5]

# Compute the robust correlations:
for(row in 1:nrow(AF4_pairs)) {
  AF4_pairs$cor_meth_exp[row] <- cor(as.numeric(as.vector((bVals_filtered_AF4[which(rownames(bVals_filtered_AF4) == AF4_pairs$Probe[row]),]))), as.numeric(as.vector((genes_all_filtered_AF4[which(rownames(genes_all_filtered_AF4) == AF4_pairs$GeneID[row]),]))), method = "pearson")
}

for(row in 1:nrow(AF9_pairs)) {
  AF9_pairs$cor_meth_exp[row] <- cor(as.numeric(as.vector((bVals_filtered_AF9[which(rownames(bVals_filtered_AF9) == AF9_pairs$Probe[row]),]))), as.numeric(as.vector((genes_all_filtered_AF9[which(rownames(genes_all_filtered_AF9) == AF9_pairs$GeneID[row]),]))), method = "pearson")
}

for(row in 1:nrow(GERM_pairs)) {
  GERM_pairs$cor_meth_exp[row] <- cor(as.numeric(as.vector((bVals_filtered_GERM[which(rownames(bVals_filtered_GERM) == GERM_pairs$Probe[row]),]))), as.numeric(as.vector((genes_all_filtered_GERM[which(rownames(genes_all_filtered_GERM) == GERM_pairs$GeneID[row]),]))), method = "pearson")
}  

for(row in 1:nrow(COMMON_pairs)) {
  COMMON_pairs$cor_meth_exp[row] <- cor(as.numeric(as.vector((bVals_filtered_COMMON[which(rownames(bVals_filtered_COMMON) == COMMON_pairs$Probe[row]),]))), as.numeric(as.vector((genes_all_filtered_COMMON[which(rownames(genes_all_filtered_COMMON) == COMMON_pairs$GeneID[row]),]))), method = "pearson")
}

keep_sides <- c("R5", "R4", "R3", "R2", "R1", "L1", "L2", "L3", "L4", "L5")
COMMON_pairs <- COMMON_pairs[which(COMMON_pairs$Sides %in% keep_sides),]
COMMON_pairs <- COMMON_pairs[which(COMMON_pairs$cor_meth_exp >= 0.5 | COMMON_pairs$cor_meth_exp <= -0.5),]
AF4_pairs <- AF4_pairs[which(AF4_pairs$Sides %in% keep_sides),]
AF4_pairs <- AF4_pairs[which(AF4_pairs$cor_meth_exp >= 0.5 | AF4_pairs$cor_meth_exp <= -0.5),]
AF9_pairs <- AF9_pairs[which(AF9_pairs$Sides %in% keep_sides),]
AF9_pairs <- AF9_pairs[which(AF9_pairs$cor_meth_exp >= 0.5 | AF9_pairs$cor_meth_exp <= -0.5),]
GERM_pairs <- GERM_pairs[which(GERM_pairs$Sides %in% keep_sides),]
GERM_pairs <- GERM_pairs[which(GERM_pairs$cor_meth_exp >= 0.5 | GERM_pairs$cor_meth_exp <= -0.5),]

colnames_all <- c("Probe", "GeneID", "Symbol", "Distance", "Sides", "Raw.p", "Pe", "log2FC_GE_LEUKEMIA.vs.B.PROGENITORS", "diff.pvalue.GE_LEUKEMIA.vs.B.PROGENITORS", "Change_leukemia", "LogFC_meth_LEUKEMIA.vs.B.PROGENITORS", "Adj.P.val_meth_LEUKEMIA.vs.B.PROGENITORS", "correlation_meth_exp")
colnames(COMMON_pairs) <- colnames_all
colnames(AF4_pairs) <- colnames_all
colnames(AF9_pairs) <- colnames_all
colnames(GERM_pairs) <- colnames_all

COMMON_pairs$Correlation_sign <- NA
AF4_pairs$Correlation_sign <- NA
AF9_pairs$Correlation_sign <- NA
GERM_pairs$Correlation_sign <- NA

COMMON_pairs$Correlation_sign[which(COMMON_pairs$correlation_meth_exp >= 0)] <- "pos"
COMMON_pairs$Correlation_sign[which(COMMON_pairs$correlation_meth_exp < 0)] <- "neg"
AF4_pairs$Correlation_sign[which(AF4_pairs$correlation_meth_exp >= 0)] <- "pos"
AF4_pairs$Correlation_sign[which(AF4_pairs$correlation_meth_exp < 0)] <- "neg"
AF9_pairs$Correlation_sign[which(AF9_pairs$correlation_meth_exp >= 0)] <- "pos"
AF9_pairs$Correlation_sign[which(AF9_pairs$correlation_meth_exp < 0)] <- "neg"
GERM_pairs$Correlation_sign[which(GERM_pairs$correlation_meth_exp >= 0)] <- "pos"
GERM_pairs$Correlation_sign[which(GERM_pairs$correlation_meth_exp < 0)] <- "neg"

colnames_arranged <- c("Probe", "GeneID", "Symbol", "Distance", "Sides", "Raw.p", "Pe", "log2FC_GE_LEUKEMIA.vs.B.PROGENITORS", "diff.pvalue.GE_LEUKEMIA.vs.B.PROGENITORS", "LogFC_meth_LEUKEMIA.vs.B.PROGENITORS", "Adj.P.val_meth_LEUKEMIA.vs.B.PROGENITORS", "correlation_meth_exp", "Correlation_sign", "Change_leukemia")
COMMON_pairs <- COMMON_pairs[,colnames_arranged]
AF4_pairs <- AF4_pairs[,colnames_arranged]
AF9_pairs <- AF9_pairs[,colnames_arranged]
GERM_pairs <- GERM_pairs[,colnames_arranged]

# Write the resulting tables:
write.table(COMMON_pairs, file = "filtered_pairs_COMMON_new_2.txt", sep = "\t", row.names = T, col.names = T, quote = F)
write.table(AF4_pairs, file = "filtered_pairs_AF4_new_2.txt", sep = "\t", row.names = T, col.names = T, quote = F)
write.table(AF9_pairs, file = "filtered_pairs_AF9_new_2.txt", sep = "\t", row.names = T, col.names = T, quote = F)
write.table(GERM_pairs, file = "filtered_pairs_GERM_new_2.txt", sep = "\t", row.names = T, col.names = T, quote = F)

