#############################################################################
### PROJECT: Differential expression analysis of Infant leukemias
### and differentiated blood cells with RNAseq data
###
### Script for the calculation of enrichments
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

###############################################################
###       Enrichment of regions (histone roadmap)           ###
###############################################################

library(magrittr)
library(dplyr)
library(tidyr)
library(ggplot2)
library(ChIPseeker)
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
library(clusterProfiler)
library(ReactomePA)
library(VennDiagram)
library(reshape2)
library(pheatmap)
library(RColorBrewer)
library(LOLA)

tablesDirectory <- ""

# Load the datasets to establish to plot the pie charts:
txdb <- TxDb.Hsapiens.UCSC.hg19.knownGene
setwd(tablesDirectory)
allprobes_cpg <- read.csv(file = "./annotation_EPIC.txt", sep = "\t", stringsAsFactors = F)
colnames(allprobes_cpg)[2] <- "start"
hypermethylation <- read.csv(file = "./annotation_GERM_hyper_probes_correlation.txt", sep = "\t", stringsAsFactors = F)
hypomethylation <- read.csv(file = "./annotation_GERM_hypo_probes_correlation.txt", sep = "\t", stringsAsFactors = F)

# Generate Granges files for the hyper and the hypomethylated probes:
hypermethylationprobes <- allprobes_cpg[which(allprobes_cpg$Name %in% hypermethylation$Name),]
hypermethylationprobes <- hypermethylationprobes[order(hypermethylationprobes[,"chr"], hypermethylationprobes[,"start"]),]
regionSethyper <- makeGRangesFromDataFrame(hypermethylationprobes, ignore.strand = TRUE, seqnames.field = "chr", start.field = "start", end.field = "end")
hypomethylationprobes <- allprobes_cpg[which(allprobes_cpg$Name %in% hypomethylation$Name),]
hypomethylationprobes <- hypomethylationprobes[order(hypomethylationprobes[,"chr"], hypomethylationprobes[,"start"]),]
regionSethypo <- makeGRangesFromDataFrame(hypomethylationprobes, ignore.strand = TRUE, seqnames.field = "chr", start.field = "start", end.field = "end")
allprobes_cpg <- allprobes_cpg[order(allprobes_cpg[,"chr"], allprobes_cpg[,"start"]),]
regionSetAll = makeGRangesFromDataFrame(allprobes_cpg, ignore.strand = TRUE, seqnames.field = "chr", start.field = "start", end.field = "end")

# Load the databases with the Regions of Interest:
# regionDB <- loadRegionDB(dbLocation = "~/Databases/regionDB/hg19", collections = "roadmap_epigenomics")


# Generate tables from lists (probes)
userSets = GRangesList(hyper = regionSethyper, hypo = regionSethypo)

locResults_hyper = runLOLA(userSets[1], regionSetAll, regionDB, cores=4)
locResults_hypo = runLOLA(userSets[2], regionSetAll, regionDB, cores=4)

write.table(locResults_hyper, file = paste(tablesDirectory,"enrichment_roadmap_epigenomics_GERM_hyper_probes.txt", sep = ""), quote = F, col.names = T, row.names = F, sep = "\t")
write.table(locResults_hypo, file = paste(tablesDirectory,"enrichment_roadmap_epigenomics_GERM_hypo_probes.txt", sep = ""), quote = F, col.names = T, row.names = F, sep = "\t")

