#############################################################################
### PROJECT: Differential expression analysis of Infant leukemias
### and differentiated blood cells with RNAseq data
###
### Script for the generation of plots from correlation analyses
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

#################################################################################
###                 Generate plots correlated genes / probes                  ###
#################################################################################

# Keep only 10L and 10R samples for each condition:
keep_sides <- c("R5", "R4", "R3", "R2", "R1", "L1", "L2", "L3", "L4", "L5")

COMMON <- read.csv("filtered_pairs_COMMON_new_2.txt", sep = "\t", stringsAsFactors = F)
AF4 <- read.csv("filtered_pairs_AF4_new_2.txt", sep = "\t", stringsAsFactors = F)
AF9 <- read.csv("filtered_pairs_AF9_new_2.txt", sep = "\t", stringsAsFactors = F)
GERM <- read.csv("filtered_pairs_GERM_new_2.txt", sep = "\t", stringsAsFactors = F)

# Convert sides variable into factor:
COMMON$Sides <- factor(COMMON$Sides, levels = keep_sides)
AF4$Sides <- factor(AF4$Sides, levels = keep_sides)
AF9$Sides <- factor(AF9$Sides, levels = keep_sides)
GERM$Sides <- factor(GERM$Sides, levels = keep_sides)

###
COMMON_pairs_hyper <- COMMON[which(COMMON$Change_leukemia == "hyper"),]
COMMON_pairs_hypo <- COMMON[which(COMMON$Change_leukemia == "hypo"),]

AF4_pairs_hyper <- AF4[which(AF4$Change_leukemia == "hyper"),]
AF4_pairs_hypo <- AF4[which(AF4$Change_leukemia == "hypo"),]

AF9_pairs_hyper <- AF9[which(AF9$Change_leukemia == "hyper"),]
AF9_pairs_hypo <- AF9[which(AF9$Change_leukemia == "hypo"),]

GERM_pairs_hyper <- GERM[which(GERM$Change_leukemia == "hyper"),]
GERM_pairs_hypo <- GERM[which(GERM$Change_leukemia == "hypo"),]

# Represent the graphs:
require(ggplot2)
require(plyr)

pdf(file="violinplots_expresssion_regulated_genes.pdf", height = 10, width = 6, onefile = TRUE)
ggplot(data=COMMON, aes(y = log2FC_GE_LEUKEMIA.vs.B.PROGENITORS, Change_leukemia, fill = Change_leukemia)) + geom_violin(trim=FALSE) + geom_boxplot(outlier.alpha = 0.1, width=0.1, fill="white") + scale_y_continuous(limits = c(-2.5, 2.5), breaks = seq(-2,2,1), labels = abs(seq(-2,2,1))) + theme_bw() + ggtitle(label = "COMMON")
ggplot(data=AF4, aes(y = log2FC_GE_LEUKEMIA.vs.B.PROGENITORS, Change_leukemia, fill = Change_leukemia)) + geom_violin(trim=FALSE) + geom_boxplot(outlier.alpha = 0.1, width=0.1, fill="white") + scale_y_continuous(limits = c(-2.5, 2.5), breaks = seq(-2,2,1), labels = abs(seq(-2,2,1))) + theme_bw() + ggtitle(label = "AF4")
ggplot(data=AF9, aes(y = log2FC_GE_LEUKEMIA.vs.B.PROGENITORS, Change_leukemia, fill = Change_leukemia)) + geom_violin(trim=FALSE) + geom_boxplot(outlier.alpha = 0.1, width=0.1, fill="white") + scale_y_continuous(limits = c(-2.5, 2.5), breaks = seq(-2,2,1), labels = abs(seq(-2,2,1))) + theme_bw() + ggtitle(label = "AF9")
ggplot(data=GERM, aes(y = log2FC_GE_LEUKEMIA.vs.B.PROGENITORS, Change_leukemia, fill = Change_leukemia)) + geom_violin(trim=FALSE) + geom_boxplot(outlier.alpha = 0.1, width=0.1, fill="white") + scale_y_continuous(limits = c(-2.5, 2.5), breaks = seq(-2,2,1), labels = abs(seq(-2,2,1))) + theme_bw() + ggtitle(label = "GERM")
dev.off()

barplot_figure <- data.frame(Group = c("COMMON", "AF4", "AF9", "GERM", "COMMON", "AF4", "AF9", "GERM"), Meth = c("hyper", "hyper", "hyper", "hyper", "hypo", "hypo", "hypo", "hypo"), Values = c(length(COMMON_pairs_hyper$Probe), length(AF4_pairs_hyper$Probe), length(AF9_pairs_hyper$Probe), length(GERM_pairs_hyper$Probe), length(COMMON_pairs_hypo$Probe), length(AF4_pairs_hypo$Probe), length(AF9_pairs_hypo$Probe), length(GERM_pairs_hypo$Probe)))
barplot_figure$Group <- factor(barplot_figure$Group, levels = c("COMMON", "AF4", "AF9", "GERM"))
pdf(file="barplot_number_correlations_new.pdf", paper = "a4r", height = 21, width = 28, onefile = TRUE)
ggplot(data=barplot_figure, aes(Group, Values, fill = Meth)) + geom_bar(stat = "identity", position=position_dodge()) + theme_bw() 
dev.off()
