#############################################################################
### PROJECT: Differential expression analysis of Infant leukemias
### and differentiated blood cells with RNAseq data
###
### Script for the generation of heatmap plots of enrichments
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

#################################################################################
###              Generate heatmaps transcription factor motifs                ###
#################################################################################

# Script to generate table with TFBS motifs from correlated probes ELMER:

library(plyr)
library(dplyr)
library(tidyr)
library(ggplot2)
library(reshape2)
library(pheatmap)
library(RColorBrewer)
library(scales)

# Load Tables
hyper_COMMON <- read.csv("getMotif.motif.enrichment_COMMON_hyper_new.csv", sep = "\t", stringsAsFactors = F)
rownames(hyper_COMMON) <- hyper_COMMON$motif
hyper_AF4 <- read.csv("getMotif.motif.enrichment_AF4_hyper_new.csv", sep = "\t", stringsAsFactors = F)
rownames(hyper_AF4) <- hyper_AF4$motif
hyper_AF9 <- read.csv("getMotif.motif.enrichment_AF9_hyper_new.csv", sep = "\t", stringsAsFactors = F)
rownames(hyper_AF9) <- hyper_AF9$motif
hyper_GERM <- read.csv("getMotif.motif.enrichment_GERM_hyper_new.csv", sep = "\t", stringsAsFactors = F)
rownames(hyper_GERM) <- hyper_GERM$motif

hypo_COMMON <- read.csv("getMotif.motif.enrichment_COMMON_hypo_new.csv", sep = "\t", stringsAsFactors = F)
rownames(hypo_COMMON) <- hypo_COMMON$motif
hypo_AF4 <- read.csv("getMotif.motif.enrichment_AF4_hypo_new.csv", sep = "\t", stringsAsFactors = F)
rownames(hypo_AF4) <- hypo_AF4$motif
hypo_AF9 <- read.csv("getMotif.motif.enrichment_AF9_hypo_new.csv", sep = "\t", stringsAsFactors = F)
rownames(hypo_AF9) <- hypo_AF9$motif
hypo_GERM <- read.csv("getMotif.motif.enrichment_GERM_hypo_new.csv", sep = "\t", stringsAsFactors = F)
rownames(hypo_GERM) <- hypo_GERM$motif

list_filter_motifs <- read.csv("List_motifs_hyper_hypo_neg_pos_correlations.txt", sep = "\t", stringsAsFactors = F)

# Filter tables
hyper_COMMON_2 <- hyper_COMMON[list_filter_motifs$Motif,]
hyper_AF4_2 <- hyper_AF4[list_filter_motifs$Motif,]
hyper_AF9_2 <- hyper_AF9[list_filter_motifs$Motif,]
hyper_GERM_2 <- hyper_GERM[list_filter_motifs$Motif,]

hypo_COMMON_2 <- hypo_COMMON[list_filter_motifs$Motif,]
hypo_AF4_2 <- hypo_AF4[list_filter_motifs$Motif,]
hypo_AF9_2 <- hypo_AF9[list_filter_motifs$Motif,]
hypo_GERM_2 <- hypo_GERM[list_filter_motifs$Motif,]

hyper <- data.frame(COMMON = hyper_COMMON_2$OR, AF4 = hyper_AF4_2$OR, AF9 = hyper_AF9_2$OR, GERM = hyper_GERM_2$OR)
rownames(hyper) <- rownames(hyper_COMMON_2)
hypo <- data.frame(COMMON = hypo_COMMON_2$OR, AF4 = hypo_AF4_2$OR, AF9 = hypo_AF9_2$OR, GERM = hypo_GERM_2$OR)
rownames(hypo) <- rownames(hypo_COMMON_2)

hyper_log <- log2(hyper)
hypo_log <- log2(hypo)

# Represent heatmaps
paletteLength <- 55
myBreaks_hyper <- c(seq(min(hyper_log), 0, length.out=ceiling(paletteLength/2) + 1), seq(max(hyper_log)/paletteLength, max(hyper_log), length.out=floor(paletteLength/2)))
myBreaks_hypo <- c(seq(min(hypo_log), 0, length.out=ceiling(paletteLength/2) + 1), seq(max(hypo_log)/paletteLength, max(hypo_log), length.out=floor(paletteLength/2)))

pdf(file="heatmap_motifs_ELMER_new_2.pdf", height=6, width=8, onefile=TRUE)
pheatmap(as.matrix(hyper_log), scale = "none", color = colorRampPalette(c("#4f99af","#f2f2f2","#a38c3a"))(55), breaks = myBreaks_hyper, border_color = "#FFFFFF", cluster_rows = F, cluster_cols = F, clustering_method = "ward.D2", main = "Heatmap Enrichment OR Motifs ELMER hyper neg", fontsize_row = 5, cellwidth = 10, cellheight = 5)  
pheatmap(as.matrix(hypo_log), scale = "none", color = colorRampPalette(c("#4f99af","#f2f2f2","#a38c3a"))(55), breaks = myBreaks_hypo, border_color = "#FFFFFF", cluster_rows = F, cluster_cols = F, clustering_method = "ward.D2", main = "Heatmap Enrichment OR Motifs ELMER hypo pos", fontsize_row = 5, cellwidth = 10, cellheight = 5)  
dev.off()


