#############################################################################
### PROJECT: Differential expression analysis of Infant leukemias
### and differentiated blood cells with RNAseq data
###
### Script for the analysis of RNAseq data
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

resultsDirectory <- ""
tablesDirectory <- ""

# Generate a 3D model of the data:
library(rgl)
library(FactoMineR)

genes_all <- read.csv(paste(tablesDirectory, "RSEM_RNAseq_genes_FPKM_matrix.tsv", sep = "/"), sep = "\t", stringsAsFactors = F)
phenodata <- read.csv(paste(tablesDirectory, "phenoData.csv", sep = "/"), sep = "\t", stringsAsFactors = F)
genes_diff_exp <- read.csv(paste(tablesDirectory, "deg_all.txt", sep = "/"), sep = "\t", stringsAsFactors = F)
rownames(genes_all) <- genes_all$ENSG_name
genes_all <- genes_all[genes_diff_exp$Genes, c(phenodata$Sample_Name_RNAseq)]
genes_all <- genes_all[complete.cases(genes_all),]
groups <- factor(phenodata$Sample_Group, levels = c("MLLAF4", "MLLAF9", "MLLWT", "ProB-fetal", "Bcell"))
pal <- factor(phenodata$color, levels = c("#D53E4F", "#2eaa6c", "#e8db4c", "#3288BD", "#993492"))
res.pca_bVals <- PCA(t(genes_all), scale.unit=TRUE, ncp=10, graph=FALSE) 
plot3d(res.pca_bVals$ind$coord[,1], res.pca_bVals$ind$coord[,2], res.pca_bVals$ind$coord[,3], col=phenodata$Sample_Color, size=2, type='s', xlab="PC1", ylab="PC2", zlab="PC3", box=F)    #Colors points by the variable coldef referencing the column Con.Abs
legend3d("topright", legend = levels(groups), pch = 16, col = levels(pal), cex=1, inset=c(0.02))
rgl.snapshot(filename=paste(resultsDirectory, "PCA_methylation_infant_leukemias_gene_expression.png", sep = "/"),fmt="png") 


# Plot heatmap genes:
library(pheatmap)
library(RColorBrewer)
genes_all <- read.csv(paste(tablesDirectory, "RSEM_RNAseq_genes_FPKM_matrix.tsv", sep = "/"),sep = "\t", stringsAsFactors = F)
phenodata <- read.csv(paste(tablesDirectory, "phenoData.csv", sep = "/"), sep = "\t", stringsAsFactors = F)
phenodata <- phenodata[is.na(phenodata),] <- "NONE"
genes_diff_exp <- read.csv(paste(tablesDirectory, "deg_all.txt", sep = "/"), sep = "\t", stringsAsFactors = F)
rownames(genes_all) <- genes_all$ENSG_name
genes_all <- genes_all[which(rownames(genes_all) %in% genes_diff_exp$Genes), c(phenodata$Sample_Name_RNAseq)]
genes_all <- genes_all + 1
genes_all <- log2(genes_all)
genes_all <- genes_all[complete.cases(genes_all),]

annotation_tissue2 <- data.frame(group = phenodata$Sample_Group)
rownames(annotation_tissue2) <- colnames(genes_all)

annotation_gender <- data.frame(cancergroup = as.character(phenodata$Gender))
rownames(annotation_gender) <- colnames(genes_all)

annotation_mutation <- data.frame(cancergroup = as.character(phenodata$Mutation))
rownames(annotation_mutation) <- colnames(genes_all)

pdf(file=paste(resultsDirectory, "heatmap_gene_expression_leukemias_with_B_cells_images.pdf", sep = "/"), paper = "a4r", height = 21, width = 28, onefile = TRUE)
pheatmap(genes_all, cluster_rows = T, cluster_cols = T, clustering_method = "ward.D2", scale = "row", color = colorRampPalette(c("Blue","white","Red"))(100), annotation_col = annotation_tissue2)
pheatmap(genes_all, cluster_rows = T, cluster_cols = T, clustering_method = "ward.D2", scale = "row", color = colorRampPalette(c("Blue","white","Red"))(100), annotation_col = annotation_gender)
pheatmap(genes_all, cluster_rows = T, cluster_cols = T, clustering_method = "ward.D2", scale = "row", color = colorRampPalette(c("Blue","white","Red"))(100), annotation_col = annotation_mutation)
dev.off()

