#############################################################################
### PROJECT: Differential expression analysis of Infant leukemias
### and differentiated blood cells with RNAseq data
###
### Script for the analysis of RNAseq data
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

resultsDirectory <- ""
tablesDirectory <- ""

# Plot upsetR gene expression:
library(UpSetR)

# Genes
AF4 <- read.csv(file = paste(tablesDirectory, "Ebseq_diff_exp_analysis_genes_AF4_vs_ProB_001FDR.tsv", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
AF4_up <- AF4[which(AF4$Change == "UP"),]
AF4_down <- AF4[which(AF4$Change == "DOWN"),]

AF9 <- read.csv(file = paste(tablesDirectory, "Ebseq_diff_exp_analysis_genes_AF9_vs_ProB_001FDR.tsv", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
AF9_up <- AF9[which(AF9$Change == "UP"),]
AF9_down <- AF9[which(AF9$Change == "DOWN"),]

WT <- read.csv(file = paste(tablesDirectory, "Ebseq_diff_exp_analysis_genes_WT_vs_ProB_001FDR.tsv", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
WT_up <- WT[which(WT$Change == "UP"),]
WT_down <- WT[which(WT$Change == "DOWN"),]

B <- read.csv(file = paste(tablesDirectory, "Ebseq_diff_exp_analysis_genes_B_vs_ProB_001FDR.tsv", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
B_up <- B[which(B$Change == "UP"),]
B_down <- B[which(B$Change == "DOWN"),]

listInput <- list(AF4_up = rownames(AF4_up), AF4_down = rownames(AF4_down), AF9_up = rownames(AF9_up), AF9_down = rownames(AF9_down), WT_up = rownames(WT_up), WT_down = rownames(WT_down), B_up = rownames(B_up), B_down = rownames(B_down))

cairo_pdf(file= paste(resultsDirectory, "upsetRplot_genes_Gene_exp_leukemias.pdf", sep = "/"), height = 8, width = 12, onefile = TRUE)
upset(fromList(listInput), order.by = "freq", nsets = 20, number.angles = 45, mainbar.y.label = "Gene overlap", sets.x.label = "Number of genes", keep.order = TRUE, mainbar.y.max = 4500)
dev.off()

# Isoforms
AF4 <- read.csv(file = paste(tablesDirectory, "Ebseq_diff_exp_analysis_isoforms_AF4_vs_ProB_001FDR.tsv", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
AF4_up <- AF4[which(AF4$Change == "UP"),]
AF4_down <- AF4[which(AF4$Change == "DOWN"),]
paste(tablesDirectory, 
AF9 <- read.csv(file = "Ebseq_diff_exp_analysis_isoforms_AF9_vs_ProB_001FDR.tsv", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
AF9_up <- AF9[which(AF9$Change == "UP"),]
AF9_down <- AF9[which(AF9$Change == "DOWN"),]

WT <- read.csv(file = paste(tablesDirectory, "Ebseq_diff_exp_analysis_isoforms_WT_vs_ProB_001FDR.tsv", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
WT_up <- WT[which(WT$Change == "UP"),]
WT_down <- WT[which(WT$Change == "DOWN"),]

B <- read.csv(file = paste(tablesDirectory, "Ebseq_diff_exp_analysis_isoforms_B_vs_ProB_001FDR.tsv", sep = "/"), header = T, stringsAsFactors = F, sep = "\t")
B_up <- B[which(B$Change == "UP"),]
B_down <- B[which(B$Change == "DOWN"),]

listInput <- list(AF4_up = rownames(AF4_up), AF4_down = rownames(AF4_down), AF9_up = rownames(AF9_up), AF9_down = rownames(AF9_down), WT_up = rownames(WT_up), WT_down = rownames(WT_down), B_up = rownames(B_up), B_down = rownames(B_down))

cairo_pdf(file= paste(resultsDirectory, "upsetRplot_isoforms_Gene_exp_leukemias.pdf", sep = "/"), height = 8, width = 12, onefile = TRUE)
upset(fromList(listInput), order.by = "freq", nsets = 12, number.angles = 45, mainbar.y.label = "Gene overlap", sets.x.label = "Number of isoforms", keep.order = TRUE, mainbar.y.max = 4500)
dev.off()
