#############################################################################
### PROJECT: Differential expression analysis of Infant leukemias
### and differentiated blood cells with RNAseq data
###
### Script for the analysis of RNAseq data
###          
###
### Authors: Juan Ramon Tejedor (Dec 2017)
#############################################################################

resultsDirectory <- ""
tablesDirectory <- ""

# Plot CV AF4, AF9, WT, B:
library(matrixStats)

# Load the datasets:
genes_all <- read.csv(paste(tablesDirectory, "RSEM_RNAseq_genes_FPKM_matrix.tsv", sep = "/"), sep = "\t", stringsAsFactors = F)
phenodata <- read.csv(paste(tablesDirectory, "phenoData.csv", sep = "/"), sep = "\t", stringsAsFactors = F)
genes_AF4 <- read.csv(paste(tablesDirectory, "Ebseq_diff_exp_analysis_genes_AF4_vs_ProB_001FDR.tsv", sep = "/"), sep = "\t", stringsAsFactors = F)
genes_AF4 <- rownames(genes_AF4)
genes_AF4 <- gsub(pattern = "_.*", replacement = "", genes_AF4)
genes_AF9 <- read.csv(paste(tablesDirectory, "Ebseq_diff_exp_analysis_genes_AF9_vs_ProB_001FDR.tsv", sep = "\t", stringsAsFactors = F)
genes_AF9 <- rownames(genes_AF9)
genes_AF9 <- gsub(pattern = "_.*", replacement = "", genes_AF9)
genes_WT <- read.csv(paste(tablesDirectory, "Ebseq_diff_exp_analysis_genes_WT_vs_ProB_001FDR.tsv", sep = "\t", stringsAsFactors = F)
genes_WT <- rownames(genes_WT)
genes_WT <- gsub(pattern = "_.*", replacement = "", genes_WT)
genes_B <- read.csv(paste(tablesDirectory, "Ebseq_diff_exp_analysis_genes_B_vs_ProB_001FDR.tsv", sep = "\t", stringsAsFactors = F)
genes_B <- rownames(genes_B)
genes_B <- gsub(pattern = "_.*", replacement = "", genes_B)
rownames(genes_all) <- genes_all$ENSG_name

genes_AF4 <- genes_all[genes_AF4, c(phenodata$Sample_Name_RNAseq[which(phenodata$Sample_Group == "MLLAF4")])]
genes_AF9 <- genes_all[genes_AF9, c(phenodata$Sample_Name_RNAseq[which(phenodata$Sample_Group == "MLLAF9")])]
genes_WT <- genes_all[genes_WT, c(phenodata$Sample_Name_RNAseq[which(phenodata$Sample_Group == "MLLWT")])]
genes_B <- genes_all[genes_B, c(phenodata$Sample_Name_RNAseq[which(phenodata$Sample_Group == "Bcell")])]
genes_AF4$CV <- sqrt(rowVars(as.matrix(genes_AF4))) / rowMeans(as.matrix(genes_AF4))
genes_AF4$Condition <- "MLLAF4"
genes_AF9$CV <- sqrt(rowVars(as.matrix(genes_AF9))) / rowMeans(as.matrix(genes_AF9))
genes_AF9$Condition <- "MLLAF9"
genes_WT$CV <- sqrt(rowVars(as.matrix(genes_WT))) / rowMeans(as.matrix(genes_WT))
genes_WT$Condition <- "nonMLL"
genes_B$CV <- sqrt(rowVars(as.matrix(genes_B))) / rowMeans(as.matrix(genes_B))
genes_B$Condition <- "Bcells"

violin_CV <- rbind(genes_AF4[,28:29], genes_AF9[6:7], genes_WT[9:10], genes_B[4:5])
violin_CV$log <- log(violin_CV$CV, 10)
violin_CV <- violin_CV[complete.cases(violin_CV),]
violin_CV$Condition <- as.factor(violin_CV$Condition)

pdf(file = paste(resultsDirectory, "~/Documents/Infant_leukemia/PDF/violinplots_coefficient_of_variationy_groups.pdf", sep = "/"), height = 21, width = 29, onefile = T)
p <- ggplot(violin_CV, aes(x=Condition, y=CV)) + geom_violin() + geom_boxplot(width=0.1) + theme_bw()
p
dev.off()

wilcox.test(x = violin_CV$log[which(violin_CV$Condition == "Bcells")], y = violin_CV$log[which(violin_CV$Condition == "MLLAF4")], conf.int = T)

