#############################################################################
### PROJECT: Differential expression analysis of Infant leukemias
### and differentiated blood cells with RNAseq data
###
### Script for the analysis of GTRD data
###          
###
### Authors: Juan Ramon Tejedor (Dec 2020)
#############################################################################

# Find DMPs between CTRL and t4:11 cells: Revision Leukemia:

# Load datasets:
bVals <- read.csv("~/Documents/Infant_leukemia/Tables/bVals_CRISPR_exp.txt", sep = "\t", stringsAsFactors = F)

bVals$AF4_vs_FLC <- bVals$AF4 - bVals$FLC
bVals$FOSL2_vs_SEM <- bVals$FOSL2 - bVals$SEM


DMPs_AF4 <- bVals[which(abs(bVals$AF4_vs_FLC) > 0.2),]
DMPs_AF4$Dir <- "hypo"
DMPs_AF4$Dir[which(DMPs_AF4$AF4_vs_FLC > 0)] <- "hyper" 
DMPs_FOSL2 <- bVals[which(abs(bVals$FOSL2_vs_SEM) > 0.4),]
DMPs_FOSL2$Dir <- "hypo"
DMPs_FOSL2$Dir[which(DMPs_FOSL2$FOSL2_vs_SEM > 0)] <- "hyper" 



###############################################################
###            Enrichment of regions (GTRDTFBS)             ###
###############################################################

library(magrittr)
library(dplyr)
library(tidyr)
library(ggplot2)
library(ChIPseeker)
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
library(clusterProfiler)
library(ReactomePA)
library(VennDiagram)
library(reshape2)
library(pheatmap)
library(RColorBrewer)
library(LOLA)

tablesDirectory <- "~/Documents/Infant_leukemia/Tables/annotations/"

# Load the datasets to establish to plot the pie charts:
txdb <- TxDb.Hsapiens.UCSC.hg19.knownGene
setwd(tablesDirectory)
allprobes_cpg <- read.csv(file = "./annotation_EPIC.txt", sep = "\t", stringsAsFactors = F)
colnames(allprobes_cpg)[2] <- "start"
# allprobes_cpg$start <- allprobes_cpg$start - 10
# allprobes_cpg$end <- allprobes_cpg$end + 10

# Generate Granges files for the hyper and the hypomethylated probes:
hypermethylationprobes <- allprobes_cpg[which(allprobes_cpg$Name %in% rownames(DMPs_AF4[which(DMPs_AF4$Dir == "hyper"),])),]
hypermethylationprobes <- hypermethylationprobes[order(hypermethylationprobes[,"chr"], hypermethylationprobes[,"start"]),]
regionSethyper <- makeGRangesFromDataFrame(hypermethylationprobes, ignore.strand = TRUE, seqnames.field = "chr", start.field = "start", end.field = "end")
hypomethylationprobes <- allprobes_cpg[which(allprobes_cpg$Name %in% rownames(DMPs_AF4[which(DMPs_AF4$Dir == "hypo"),])),]
regionSethypo <- makeGRangesFromDataFrame(hypomethylationprobes, ignore.strand = TRUE, seqnames.field = "chr", start.field = "start", end.field = "end")
allprobes_cpg <- allprobes_cpg[order(allprobes_cpg[,"chr"], allprobes_cpg[,"start"]),]
regionSetAll = makeGRangesFromDataFrame(allprobes_cpg, ignore.strand = TRUE, seqnames.field = "chr", start.field = "start", end.field = "end")

# Load the databases with the Regions of Interest:
regionDB <- loadRegionDB(dbLocation = "~/Databases/regionDB/hg19", collections = "GTRD_tfbs")

# Generate tables from lists (probes)
userSets = GRangesList(hyper = regionSethyper, hypo = regionSethypo)

locResults_hyper = runLOLA(userSets[1], regionSetAll, regionDB, cores=4)
locResults_hypo = runLOLA(userSets[2], regionSetAll, regionDB, cores=4)

write.table(locResults_hyper, file = paste(tablesDirectory,"enrichment_GTRD_tfbs_hyper_AF4_vs_FLC_revision.txt", sep = ""), quote = F, col.names = T, row.names = F, sep = "\t")
write.table(locResults_hypo, file = paste(tablesDirectory,"enrichment_GTRD_tfbs_hypo_AF4_vs_FLC_revision.txt", sep = ""), quote = F, col.names = T, row.names = F, sep = "\t")

